<?php
namespace Elementor;
class Webnus_Element_Widgets_Blog extends \Elementor\Widget_Base {

	/**
	 * Retrieve widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {

		return 'blog';

	}

	/**
	 * Retrieve widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {

		return esc_html__( 'Webnus Blog', 'deep' );

	}

	/**
	 * Retrieve widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {

		return 'eicon-post-list';

	}

	/**
	 * Set widget category.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget category.
	 */
	public function get_categories() {

		return [ 'webnus' ];

	}

	/**
	 * enqueue CSS 
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_style_depends() {

		return [ 'wn-deep-blog' ];
		
	}

	/**
	 * enqueue JS 
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_script_depends() {

		return [ 'wnblog', 'jquery-masonry' ];
		
	}

	/**
	 * Register widget controls.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

    // Content Tab
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'General', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
		);
		$this->add_control(
			'type',
			[
				'label' =>  esc_html__( 'Type', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'description' =>  esc_html__( 'Blog type layout', 'deep'),
				'options'			=> [
					'1'		=>	'Large Posts ( Default )',
					'2'		=>	'List Posts ( Default )',
					'3'		=>	'Grid Posts ( Default )',
					'4'		=>	'First Large then List ( Default )',
					'5'		=>	'First Large then Grid ( Default )',
					'6'		=>	'Large Posts ( Personal blog )',
					'7'		=>	'List Posts ( Personal blog )',
					'8'		=>	'Grid Posts ( Personal blog )',
					'9'		=>	'First Large then List ( Personal blog )',
					'10'	=>	'First Large then Grid ( Personal blog )',
					'11'	=>	'Large Posts ( Magazine )',
					'12'	=>	'List Posts ( Magazine )',
					'13'	=>	'Grid Posts ( Magazine )',
					'14'	=>	'First Large then List ( Magazine )',
					'15'	=>	'First Large then Grid ( Magazine )',
					'16'	=>	'Masonry',
					'17'	=>	'Timeline',
					'18'	=>	'Large Posts ( Minimal )',
					'19'	=>	'List Posts ( Minimal )',
					'20'	=>	'Grid Posts ( Minimal )',
					'21'	=>	'First Large then List ( Minimal )',
					'22'	=>	'First Large then Grid ( Minimal )',
				],
				'default' 	=> '1',
			]
		);

		$this->add_control(
			'sidebar',
			[
				'label' =>  esc_html__( 'Sidebar', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'description' =>  esc_html__( 'Sidebar does not support Masonry and Timeline', 'deep'),
				'options'			=> [
					'none'		=> 'None',
					'left'		=> 'Left',
					'right'		=> 'Right',
					'both'		=> 'Both',
				],
				'default'	=>	'none',
				'condition'	=>	[
					'type!'	=>	[
						'16',
						'17',
					]
				]
			]
		);
		$categories = array();
		$categories = get_categories();
		$category_slug_array = array('');
		$category_name_array = array('');
		foreach( $categories as $category ) {
			$category_slug_array[] = $category->name;
			$category_name_array[] = $category->slug;
		}
		$category_array  = array_combine($category_slug_array, $category_name_array);
		$this->add_control(
			'category',
			[
				'label' =>  esc_html__( 'Category', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'description' =>  esc_html__( 'Select specific category, leave blank to show all categories.', 'deep'),
				'options'			=> $category_array,
			]
		);
		$this->add_control(
			'count',
			[
				'label' 		=>  esc_html__( 'Post Count', 'deep' ), //heading
				'type' 			=> \Elementor\Controls_Manager::TEXT, //type
				'description'	=>  esc_html__( 'Number of post(s) to show', 'deep')
			]
		);
		$this->add_control(
			'orderby',
			[
				'label' =>  esc_html__( 'Order By', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'description' =>  esc_html__( 'If you use "Social Post Score" type, then Social Metrics Tracker plugin must be activated via Apperance > Install Plugins.', 'deep'),
				'options'			=> [
					'date'	=>	 esc_html__( 'Date (Latest Posts)', 'deep' ),
					'comment_count'	=>	 esc_html__( 'Popular posts: Comment Count', 'deep' ),
					'view_count'	=>	 esc_html__( 'Popular posts: View Count', 'deep' ),
					'social_score'	=>	 esc_html__( 'Popular Posts: Social Score', 'deep' ),
				]
			]
		);
		$this->add_control(
			'loadmore_btn',
			[
				'label'		=>  esc_html__( 'Do you want load more button?', 'deep' ),
				'description'	=>  esc_html__( 'if you select it, this option will add a button below the shortcode to load more post to show', 'deep'),
				'type' 			=> \Elementor\Controls_Manager::SWITCHER, //type
				'label_on' 		=>  esc_html__( 'Yes', 'deep' ),
				'label_off' 	=>  esc_html__( 'No', 'deep' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'no',
				'condition'		=>	[
					'type!'	=>	[
						'16'
					]
				],
			]
		);

    $this->end_controls_section();
		$this->start_controls_section(
			'classid_section',
			[
				'label' => esc_html__( 'Class & ID', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'shortcodeclass',
			[
				'label'	=>  esc_html__( 'Extra Class', 'deep' ),
				'type'	=> \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'shortcodeid',
			[
				'label'	=>  esc_html__( 'ID', 'deep' ),
				'type'	=> \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->end_controls_section();


		// Wrapper Style
		$this->start_controls_section(
			'section_wrap_style',
			[
				'label' => __( 'Wrap Style', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'wrap_text_align',
			[
				'label'     => __( 'Text align', 'deep' ),
				'type'      => \Elementor\Controls_Manager::CHOOSE,
				'options'   => [
					'left'   => [
						'title' => __( 'Left', 'deep' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'deep' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'  => [
						'title' => __( 'Right', 'deep' ),
						'icon'  => 'fa fa-align-right',
					],
				],				
				'toggle'    => true,
				'selectors' => [
					'#wrap {{WRAPPER}} .blg-def-grid, #wrap {{WRAPPER}} .blg-def-list, #wrap {{WRAPPER}} .blg-def-full' => 'text-align: {{VALUE}}',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'wrap_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
    );
    
    $this->add_responsive_control(
			'wrap_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'display: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->start_controls_tabs(
			'wrap_style_tabs'
		);

		$this->start_controls_tab(
			'style_wrap_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'wrap_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .wn-blog-ajax',
			]
		);

		$this->add_control(
			'wrap_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'wrap_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-blog-ajax',
				]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wrap_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-blog-ajax',
			]
		);
		
		$this->add_control(
			'wrap_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'wrap_padding', 
			[
				'label' 		=> __( 'wrap padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices'	=> [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'wrap_margin', 
			[
				'label' 		=> __( 'wrap margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices'	=> [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_wrap_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'wrap_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradient',],
				'selector' => '#wrap {{WRAPPER}} .wn-blog-ajax:hover',
			]
		);	

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wrap_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-blog-ajax:hover',
			]
		);	
		
		$this->add_control(
			'wrap_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'wrap_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax:hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'wrap_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-blog-ajax:hover',
				]
		);

		$this->add_responsive_control(
			'wrap_padding_hover', 
			[
				'label' 		=> __( 'wrap padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices'	=> [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'wrap_margin_hover', 
			[
				'label' 		=> __( 'wrap margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices'	=> [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'wrap_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'wrap_size',
			[
				'label' => __( 'Width & Height', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					''  => __( 'Default', 'deep' ),
					'auto'  => __( 'Auto', 'deep' ),
					'100%'  => __( 'Full-Width(100%)', 'deep' ),
					'custom'  => __( 'Custom', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'width: {{VALUE}}',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'wrap_size_width',
			[
				'label' => __( 'Width', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1920,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'width: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'wrap_size'      => array( 'custom' ),
				),
			]
		);

		$this->add_responsive_control(
			'wrap_size_max_width',
			[
				'label' => __( 'Max Width', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1920,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'max-width: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'wrap_size'      => array( 'custom' ),
				),
			]
		);

		$this->add_responsive_control(
			'wrap_size_height',
			[
				'label' => __( 'Height', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 500,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'height: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'wrap_size'      => array( 'custom' ),
				),
			]
		);

		$this->add_responsive_control(
			'wrap_size_max_height',
			[
				'label' => __( 'Max Height', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 500,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blog-ajax' => 'max-height: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'wrap_size'      => array( 'custom' ),
				),
			]
		);

		$this->add_control(
			'post_meta_data',
			[
				'label'     => __( 'Post Meta Data', 'deep' ),
				'type'      => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'post_meta_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .postmetadata' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
    );
    
    $this->add_responsive_control(
			'post_meta_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .postmetadata' => 'display: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'post_meta_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .postmetadata',
			]
		);

		$this->add_control(
			'post_meta_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .postmetadata' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'post_meta_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .postmetadata',
				]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'post_meta_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .postmetadata',
			]
		);
		
		$this->add_control(
			'post_meta_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .postmetadata' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'post_meta_padding', 
			[
				'label' 		=> __( 'Post Meta padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .postmetadata' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'post_meta_margin', 
			[
				'label' 		=> __( 'Post Meta margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .postmetadata' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_section();

		// Title Style
		$this->start_controls_section(
			'section_title_style',
			[
				'label' => __( 'Title style', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_text_align',
			[
				'label'     => __( 'Text align', 'deep' ),
				'type'      => \Elementor\Controls_Manager::CHOOSE,
				'options'   => [
					'left'   => [
						'title' => __( 'Left', 'deep' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'deep' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'  => [
						'title' => __( 'Right', 'deep' ),
						'icon'  => 'fa fa-align-right',
					],
				],				
				'toggle'    => true,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3,#wrap {{WRAPPER}} .pin-ecxt h4,#wrap {{WRAPPER}} .tline-ecxt h4' => 'text-align: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'title_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3,#wrap {{WRAPPER}} .pin-ecxt h4,#wrap {{WRAPPER}} .tline-ecxt h4' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
    );
    
    $this->add_control(
			'title_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3,#wrap {{WRAPPER}} .pin-ecxt h4,#wrap {{WRAPPER}} .tline-ecxt h4' => 'display: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'title_style_tabs'
		);

		$this->start_controls_tab(
			'style_title_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'title_typography',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-blogws-wrap h3 a,#wrap {{WRAPPER}} .pin-ecxt h4 a ,#wrap {{WRAPPER}} .tline-ecxt h4 a',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' 		=> __( 'Color', 'deep' ), //heading
				'type' 			=> \Elementor\Controls_Manager::COLOR, //type
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3 a,#wrap {{WRAPPER}} .pin-ecxt h4 a ,#wrap {{WRAPPER}} .tline-ecxt h4 a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap h3 a,#wrap {{WRAPPER}} .pin-ecxt h4 a ,#wrap {{WRAPPER}} .tline-ecxt h4 a',
			]
		);

		$this->add_control(
			'title_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3 a,#wrap {{WRAPPER}} .pin-ecxt h4 a ,#wrap {{WRAPPER}} .tline-ecxt h4 a' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'title_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap h3 a,#wrap {{WRAPPER}} .pin-ecxt h4 a ,#wrap {{WRAPPER}} .tline-ecxt h4 a',
				]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'title_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap h3 a,#wrap {{WRAPPER}} .pin-ecxt h4 a ,#wrap {{WRAPPER}} .tline-ecxt h4 a',
			]
		);
		
		$this->add_control(
			'title_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3 a,#wrap {{WRAPPER}} .pin-ecxt h4 a ,#wrap {{WRAPPER}} .tline-ecxt h4 a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'title_padding', 
			[
				'label' 		=> __( 'Title padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3,#wrap {{WRAPPER}} .pin-ecxt h4,#wrap {{WRAPPER}} .tline-ecxt h4' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'title_margin', 
			[
				'label' 		=> __( 'Title margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3,#wrap {{WRAPPER}} .pin-ecxt h4 ,#wrap {{WRAPPER}} .tline-ecxt h4 ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_title_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'title_typography_hover',
				'label' 	=> __( 'Title Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-blogws-wrap h3 a:hover,#wrap {{WRAPPER}} .pin-ecxt h4 a:hover ,#wrap {{WRAPPER}} .tline-ecxt h4 a:hover',
			]
		);

		$this->add_control(
			'title_color_hover', 
			[
				'label' 		=> __( 'Title color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3 a:hover,#wrap {{WRAPPER}} .pin-ecxt h4 a:hover ,#wrap {{WRAPPER}} .tline-ecxt h4 a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap h3 a:hover,#wrap {{WRAPPER}} .pin-ecxt h4 a:hover ,#wrap {{WRAPPER}} .tline-ecxt h4 a:hover',
			]
		);	

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'title_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap h3 a:hover,#wrap {{WRAPPER}} .pin-ecxt h4 a:hover ,#wrap {{WRAPPER}} .tline-ecxt h4 a:hover',
			]
		);	
		
		$this->add_control(
			'title_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3 a:hover,#wrap {{WRAPPER}} .pin-ecxt h4 a:hover ,#wrap {{WRAPPER}} .tline-ecxt h4 a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'title_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3 a:hover,#wrap {{WRAPPER}} .pin-ecxt h4 a:hover ,#wrap {{WRAPPER}} .tline-ecxt h4 a:hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'title_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap h3 a:hover,#wrap {{WRAPPER}} .pin-ecxt h4 a:hover ,#wrap {{WRAPPER}} .tline-ecxt h4 a:hover',
				]
		);

		$this->add_responsive_control(
			'title_padding_hover', 
			[
				'label' 		=> __( 'Title padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3:hover,#wrap {{WRAPPER}} .pin-ecxt h4:hover ,#wrap {{WRAPPER}} .tline-ecxt h4:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'title_margin_hover', 
			[
				'label' 		=> __( 'Title margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3:hover,#wrap {{WRAPPER}} .pin-ecxt h4:hover ,#wrap {{WRAPPER}} .tline-ecxt h4:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'title_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3 a,#wrap {{WRAPPER}} .pin-ecxt h4 a ,#wrap {{WRAPPER}} .tline-ecxt h4 a' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);
		
		$this->add_responsive_control(
			'title_position',
			[
				'label' => __( 'Position', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					''  => __( 'Default', 'deep' ),
					'relative'  => __( 'Relative', 'deep' ),
					'absolute' => __( 'Absolute', 'deep' ),
					'fixed' => __( 'Fixed', 'deep' ),
					'static' => __( 'Static', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3,#wrap {{WRAPPER}} .pin-ecxt h4,#wrap {{WRAPPER}} .tline-ecxt h4' => 'position: {{VALUE}}',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'title_pos_top',
			[
				'label' => __( 'Top', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3,#wrap {{WRAPPER}} .pin-ecxt h4,#wrap {{WRAPPER}} .tline-ecxt h4' => 'top: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'title_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'title_pos_right',
			[
				'label' => __( 'Right', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3,#wrap {{WRAPPER}} .pin-ecxt h4,#wrap {{WRAPPER}} .tline-ecxt h4' => 'right: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'title_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'title_pos_bottom',
			[
				'label' => __( 'Bottom', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3,#wrap {{WRAPPER}} .pin-ecxt h4,#wrap {{WRAPPER}} .tline-ecxt h4' => 'bottom: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'title_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'title_pos_left',
			[
				'label' => __( 'Left', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap h3,#wrap {{WRAPPER}} .pin-ecxt h4,#wrap {{WRAPPER}} .tline-ecxt h4' => 'left: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'title_position'      => array( 'relative','absolute','fixed' ),
				),
			]
    );

		$this->end_controls_section();

		// Content Style
		$this->start_controls_section(
			'section_content_style',
			[
				'label' => __( 'Content style', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'content_text_align',
			[
				'label'     => __( 'Text align', 'deep' ),
				'type'      => \Elementor\Controls_Manager::CHOOSE,
				'options'   => [
					'left'   => [
						'title' => __( 'Left', 'deep' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'deep' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'  => [
						'title' => __( 'Right', 'deep' ),
						'icon'  => 'fa fa-align-right',
					],
				],				
				'toggle'    => true,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'text-align: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'content_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
    );

		$this->add_responsive_control(
			'content_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'display: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->start_controls_tabs(
			'content_style_tabs'
		);

		$this->start_controls_tab(
			'style_content_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'content_typography',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-blogws-wrap p',
			]
		);

		$this->add_control(
			'content_color',
			[
				'label' 		=> __( 'Color', 'deep' ), //heading
				'type' 			=> \Elementor\Controls_Manager::COLOR, //type
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'content_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap p',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'content_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap p',
			]
		);
		
		$this->add_control(
			'content_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'content_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'content_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap p',
				]
		);

		$this->add_responsive_control(
			'content_padding', 
			[
				'label' 		=> __( 'Content padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'content_margin', 
			[
				'label' 		=> __( 'Content margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_content_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'content_typography_hover',
				'label' 	=> __( 'Content Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-blogws-wrap p:hover',
			]
		);

		$this->add_control(
			'content_color_hover', 
			[
				'label' 		=> __( 'Content color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'content_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap p:hover',
			]
		);		

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'content_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap p:hover',
			]
		);
		
		$this->add_control(
			'content_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'content_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p:hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'content_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap p:hover',
				]
		);

		$this->add_responsive_control(
			'content_padding_hover', 
			[
				'label' 		=> __( 'Content padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'content_margin_hover', 
			[
				'label' 		=> __( 'Content margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'content_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);
		
		$this->add_responsive_control(
			'content_position',
			[
				'label' => __( 'Position', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					''  => __( 'Default', 'deep' ),
					'relative'  => __( 'Relative', 'deep' ),
					'absolute' => __( 'Absolute', 'deep' ),
					'fixed' => __( 'Fixed', 'deep' ),
					'static' => __( 'Static', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'position: {{VALUE}}',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'content_pos_top',
			[
				'label' => __( 'Top', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'top: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'content_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'content_pos_right',
			[
				'label' => __( 'Right', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'right: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'content_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'content_pos_bottom',
			[
				'label' => __( 'Bottom', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'bottom: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'content_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'content_pos_left',
			[
				'label' => __( 'Left', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap p' => 'left: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'content_position'      => array( 'relative','absolute','fixed' ),
				),
			]
    );

		$this->end_controls_section();

		// Category Styles
		$this->start_controls_section(
			'section_category_style',
			[
				'label' => __( 'Category Style', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition'	=>	[
					'type!'	=>	[
						'11','12','13','14','15','17','19',
					]
				]
			]
		);

		$this->add_responsive_control(
			'category_align',
			[
				'label' => __( 'Text Alignment', 'deep' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'deep' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'deep' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'deep' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'toggle' => true,
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat' => 'text-align: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'category_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'category_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat' => 'display: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->start_controls_tabs(
			'category_style_tabs'
		);

		$this->start_controls_tab(
			'style_category_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'category_typography',
				'label' 	=> __( 'Category Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .blog-cat a',
			]
		);

		$this->add_control(
			'category_color', 
			[
				'label' 		=> __( 'Category color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-cat a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'category_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .blog-cat a',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'category_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-cat',
			]
		);
		
		$this->add_control(
			'category_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'category_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat a' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'category_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-cat a',
				]
		);

		$this->add_responsive_control(
			'category_padding', 
			[
				'label' 		=> __( 'Category padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'category_margin', 
			[
				'label' 		=> __( 'Category margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_category_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'category_typography_hover',
				'label' 	=> __( 'Category Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .blog-cat a:hover',
			]
		);

		$this->add_control(
			'category_color_hover', 
			[
				'label' 		=> __( 'Category color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-cat a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'category_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .blog-cat a:hover',
			]
		);	

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'category_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-cat:hover',
			]
		);
		
		$this->add_control(
			'category_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'category_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat a:hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'category_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-cat a:hover',
				]
		);

		$this->add_responsive_control(
			'category_padding_hover', 
			[
				'label' 		=> __( 'Category padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat a:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'category_margin_hover', 
			[
				'label' 		=> __( 'Category margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat a:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'category_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat a' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
    );

		$this->add_control(
			'icon_category_heading',
			[
				'label' => __( 'Icon Styles', 'deep' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'icon_category_size',
			[
				'label' 		=> __( 'Size', 'deep' ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' 	=> [ 'px', '%' ],
				'range' 		=> [
					'px' 		=> [
						'min' 		=> 0,
						'max' 		=> 200,
						'step' 		=> 1,
					],
					'%' 		=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-cat i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'icon_category_color', 
			[
				'label' 		=> __( 'Icon Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-cat i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'color_icon_category_hover', 
			[
				'label' 		=> __( 'Icon Color Hover', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-cat:hover i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();

		// Readmore Styles
		$this->start_controls_section(
			'section_readmore_style',
			[
				'label' => __( 'Button style', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'button_align',
			[
				'label' => __( 'Content Alignment', 'deep' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'deep' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'deep' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'deep' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'toggle' => true,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-loadmore-ajax' => 'text-align: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'button_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-loadmore-ajax' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'button_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-loadmore-ajax' => 'display: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->start_controls_tabs(
			'button_style_tabs'
		);

		$this->start_controls_tab(
			'style_button_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'readmore_typography',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a',
			]
		);

		$this->add_control(
			'readmore_color',
			[
				'label' 		=> __( 'Color', 'deep' ), //heading
				'type' 			=> \Elementor\Controls_Manager::COLOR, //type
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'readmore_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'readmore_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a',
			]
		);
		
		$this->add_control(
			'readmore_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'readmore_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'readmore_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a',
				]
		);

		$this->add_responsive_control(
			'readmore_padding', 
			[
				'label' 		=> __( 'padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'readmore_margin', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_button_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'readmore_typography_hover',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-blogws-wrap .readmore:hover, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a:hover',
			]
		);

		$this->add_control(
			'readmore_color_hover',
			[
				'label' 		=> __( 'Color', 'deep' ), //heading
				'type' 			=> \Elementor\Controls_Manager::COLOR, //type
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore:hover, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a:hover' => 'color: {{VALUE}} !important',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'readmore_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap .readmore:hover, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a:hover',
			]
		);		

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'readmore_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap .readmore:hover, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a:hover',
			]
		);
		
		$this->add_control(
			'readmore_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore:hover, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'readmore_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore:hover, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a:hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'readmore_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap .readmore:hover, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a:hover',
				]
		);

		$this->add_responsive_control(
			'readmore_padding_hover', 
			[
				'label' 		=> __( 'padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore:hover, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'readmore_margin_hover', 
			[
				'label' 		=> __( 'margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore:hover, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'button_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
    );
    
    $this->add_responsive_control(
			'button_position',
			[
				'label' => __( 'Position', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					''  => __( 'Default', 'deep' ),
					'relative'  => __( 'Relative', 'deep' ),
					'absolute' => __( 'Absolute', 'deep' ),
					'fixed' => __( 'Fixed', 'deep' ),
					'static' => __( 'Static', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a' => 'position: {{VALUE}}',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'button_pos_top',
			[
				'label' => __( 'Top', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a' => 'top: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'button_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'button_pos_right',
			[
				'label' => __( 'Right', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a' => 'right: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'button_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'button_pos_bottom',
			[
				'label' => __( 'Bottom', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a' => 'bottom: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'button_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'button_pos_left',
			[
				'label' => __( 'Left', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-blogws-wrap .readmore, #wrap {{WRAPPER}} .wn-blogws-wrap .wn-loadmore-ajax a' => 'left: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'button_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);
		
		$this->end_controls_section();

		// Date Style
		$this->start_controls_section(
			'section_dates_style',
			[
				'label' => __( 'Dates Style', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition'	=>	[
					'type!'	=>	[
						'11','13','14','15','20','17',
					]
				]
			]
		);

		$this->add_responsive_control(
			'dates_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date a, #wrap {{WRAPPER}} .blog-date' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
    );

		$this->add_responsive_control(
			'dates_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date a, #wrap {{WRAPPER}} .blog-date' => 'display: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->start_controls_tabs(
			'dates_style_tabs'
		);

		$this->start_controls_tab(
			'style_dates_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'dates_typography',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .blog-date a, #wrap {{WRAPPER}} .blog-date',
			]
		);

		$this->add_control(
			'dates_color', 
			[
				'label' 		=> __( 'Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-date a, #wrap {{WRAPPER}} .blog-date' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'dates_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .blog-date a, #wrap {{WRAPPER}} .blog-date',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'dates_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-date a, #wrap {{WRAPPER}} .blog-date',
			]
		);
		
		$this->add_control(
			'dates_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date a, #wrap {{WRAPPER}} .blog-date' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'dates_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date a, #wrap {{WRAPPER}} .blog-date' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'dates_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-date a, #wrap {{WRAPPER}} .blog-date',
				]
		);

		$this->add_responsive_control(
			'dates_padding', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date a, #wrap {{WRAPPER}} .blog-date' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'dates_margin', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date a, #wrap {{WRAPPER}} .blog-date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_dates_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'dates_typography_hover',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .blog-date a:hover, #wrap {{WRAPPER}} .blog-date:hover',
			]
		);

		$this->add_control(
			'dates_color_hover', 
			[
				'label' 		=> __( 'Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-date a:hover, #wrap {{WRAPPER}} .blog-date:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'dates_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .blog-date a:hover, #wrap {{WRAPPER}} .blog-date:hover',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'dates_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-date a:hover, #wrap {{WRAPPER}} .blog-date:hover',
			]
		);
		
		$this->add_control(
			'dates_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date a:hover, #wrap {{WRAPPER}} .blog-date:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'dates_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date a:hover, #wrap {{WRAPPER}} .blog-date:hover' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'dates_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-date a:hover, #wrap {{WRAPPER}} .blog-date:hover',
				]
		);

		$this->add_responsive_control(
			'dates_padding_hover', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date a:hover, #wrap {{WRAPPER}} .blog-date:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'dates_margin_hover', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date a:hover, #wrap {{WRAPPER}} .blog-date:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'dates_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date a,#wrap {{WRAPPER}} .blog-date i , #wrap {{WRAPPER}} .blog-date' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->add_control(
			'icon_dates_heading',
			[
				'label' => __( 'Icon Styles', 'deep' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'icon_dates_size',
			[
				'label' 		=> __( 'Size', 'deep' ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' 	=> [ 'px', '%' ],
				'range' 		=> [
					'px' 		=> [
						'min' 		=> 0,
						'max' 		=> 200,
						'step' 		=> 1,
					],
					'%' 		=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-date i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'icon_dates_color', 
			[
				'label' 		=> __( 'Icon Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-date i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'color_icon_dates_hover', 
			[
				'label' 		=> __( 'Icon Color Hover', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-date:hover i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();
		
		$this->end_controls_section();

		// Comment Style
		$this->start_controls_section(
			'section_comments_style',
			[
				'label' => __( 'Comments Style', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition'	=>	[
					'type'	=>	[
						'1','2','3','4','5','17','19','21','22',
					]
				]
			]
		);
		
		$this->add_responsive_control(
			'comments_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'comments_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments' => 'display: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->start_controls_tabs(
			'comments_style_tabs'
		);

		$this->start_controls_tab(
			'style_comments_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'comments_typography',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .blog-comments a',
			]
		);

		$this->add_control(
			'comments_color', 
			[
				'label' 		=> __( 'Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-comments a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'comments_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .blog-comments a',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'comments_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-comments a',
			]
		);
		
		$this->add_control(
			'comments_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'comments_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments a' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'comments_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-comments a',
				]
		);

		$this->add_responsive_control(
			'comments_padding', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'comments_margin', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	


		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_comments_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'comments_typography_hover',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .blog-comments a:hover',
			]
		);

		$this->add_control(
			'comments_color_hover', 
			[
				'label' 		=> __( 'Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-comments a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'comments_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .blog-comments a:hover',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'comments_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-comments a:hover',
			]
		);
		
		$this->add_control(
			'comments_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'comments_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments a:hover' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'comments_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-comments a:hover',
				]
		);

		$this->add_responsive_control(
			'comments_padding_hover', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments a:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'comments_margin_hover', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments a:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'comments_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments a, #wrap {{WRAPPER}} .blog-comments i' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->add_control(
			'icon_comments_heading',
			[
				'label' => __( 'Icon Styles', 'deep' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'icon_comments_size',
			[
				'label' 		=> __( 'Size', 'deep' ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' 	=> [ 'px', '%' ],
				'range' 		=> [
					'px' 		=> [
						'min' 		=> 0,
						'max' 		=> 200,
						'step' 		=> 1,
					],
					'%' 		=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-comments i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'icon_comments_color', 
			[
				'label' 		=> __( 'Icon Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-comments i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'color_icon_comments_hover', 
			[
				'label' 		=> __( 'Icon Color Hover', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-comments:hover i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_section();

		// Author Style
		$this->start_controls_section(
			'section_author_style',
			[
				'label' => __( 'Author Style', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'author_text_align',
			[
				'label'     => __( 'Text align', 'deep' ),
				'type'      => \Elementor\Controls_Manager::CHOOSE,
				'options'   => [
					'left'   => [
						'title' => __( 'Left', 'deep' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'deep' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'  => [
						'title' => __( 'Right', 'deep' ),
						'icon'  => 'fa fa-align-right',
					],
				],				
				'toggle'    => true,
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author, #wrap {{WRAPPER}} .latest-author' => 'text-align: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'author_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author, #wrap {{WRAPPER}} .latest-author' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_control(
			'author_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author, #wrap {{WRAPPER}} .latest-author' => 'display: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'author_style_tabs'
		);

		$this->start_controls_tab(
			'style_author_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'author_typography',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a',
			]
		);

		$this->add_control(
			'post_author_color',
			[
				'label'     => esc_html__( 'Color', 'deep' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'author_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a',
			]
		);

		$this->add_control(
			'author_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'author_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a',
				]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'author_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a',
			]
		);

		$this->add_control(
			'author_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'author_padding', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'author_margin', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_author_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'author_typography_hover',
				'label' 	=> __( ' Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .blog-author a:hover, #wrap {{WRAPPER}} .latest-author a:hover',
			]
		);

		$this->add_control(
			'author_color_hover', 
			[
				'label' 		=> __( 'Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-author a:hover, #wrap {{WRAPPER}} .latest-author a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'author_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .blog-author a:hover, #wrap {{WRAPPER}} .latest-author a:hover',
			]
		);	

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'author_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-author a:hover, #wrap {{WRAPPER}} .latest-author a:hover',
			]
		);	
		
		$this->add_control(
			'author_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a:hover, #wrap {{WRAPPER}} .latest-author a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'author_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a:hover, #wrap {{WRAPPER}} .latest-author a:hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'author_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-author a:hover, #wrap {{WRAPPER}} .latest-author a:hover',
				]
		);

		$this->add_responsive_control(
			'author_padding_hover', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a:hover, #wrap {{WRAPPER}} .latest-author a:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'author_margin_hover', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a:hover, #wrap {{WRAPPER}} .latest-author a:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'author_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'author_position',
			[
				'label' => __( 'Position', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					''  => __( 'Default', 'deep' ),
					'relative'  => __( 'Relative', 'deep' ),
					'absolute' => __( 'Absolute', 'deep' ),
					'fixed' => __( 'Fixed', 'deep' ),
					'static' => __( 'Static', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a' => 'position: {{VALUE}}',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'author_pos_top',
			[
				'label' => __( 'Top', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a' => 'top: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'author_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'author_pos_right',
			[
				'label' => __( 'Right', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a' => 'right: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'author_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'author_pos_bottom',
			[
				'label' => __( 'Bottom', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a' => 'bottom: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'author_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'author_pos_left',
			[
				'label' => __( 'Left', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author a, #wrap {{WRAPPER}} .latest-author a' => 'left: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'author_position'      => array( 'relative','absolute','fixed' ),
				),
			]
    );
		
		$this->add_control(
			'author_img_heading',
			[
				'label' => __( 'Author Image', 'deep' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'author_image_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author img, #wrap {{WRAPPER}} .latest-author img, #wrap {{WRAPPER}} .au-avatar-box .au-avatar img' => 'display: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'author_img_style_tabs'
		);

		$this->start_controls_tab(
			'style_author_img_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Css_Filter::get_type(),
			[
				'name'     => 'author_img_filters',
				'label' => __( 'Image Filter', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-author img, #wrap {{WRAPPER}} .latest-author img, #wrap {{WRAPPER}} .au-avatar-box .au-avatar img',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'author_images_bg',
				'label'    => __( 'Background', 'deep' ),
				'types'    => [ 'classic' , 'gradient' ],
				'selector' => '#wrap {{WRAPPER}} .blog-author img, #wrap {{WRAPPER}} .latest-author img, #wrap {{WRAPPER}} .au-avatar-box .au-avatar img',
			]
		);		

		$this->add_control(
			'author_img_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author img, #wrap {{WRAPPER}} .latest-author img, #wrap {{WRAPPER}} .au-avatar-box .au-avatar img' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'author_img_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-author img, #wrap {{WRAPPER}} .latest-author img, #wrap {{WRAPPER}} .au-avatar-box .au-avatar img',
				]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'author_img_border',
				'label'    => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-author img, #wrap {{WRAPPER}} .latest-author img, #wrap {{WRAPPER}} .au-avatar-box .au-avatar img',
			]
		);

		$this->add_control(
			'author_img_border_radius',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .blog-author img, #wrap {{WRAPPER}} .latest-author img, #wrap {{WRAPPER}} .au-avatar-box .au-avatar img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'author_img_padding',
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .blog-author img, #wrap {{WRAPPER}} .latest-author img, #wrap {{WRAPPER}} .au-avatar-box .au-avatar img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'author_img_margin',
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .blog-author img, #wrap {{WRAPPER}} .latest-author img, #wrap {{WRAPPER}} .au-avatar-box .au-avatar img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_author_img_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Css_Filter::get_type(),
			[
				'name'     => 'author_img_filters_hover',
				'label' => __( 'Image Filter', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-author:hover img, #wrap {{WRAPPER}} .latest-author:hover img, #wrap {{WRAPPER}} .au-avatar-box:hover .au-avatar img, #wrap {{WRAPPER}} .au-avatar-box:hover .au-avatar img',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'author_images_bg_hover',
				'label'    => __( 'Background', 'deep' ),
				'types'    => [ 'classic' , 'gradient' ],
				'selector' => '#wrap {{WRAPPER}} .blog-author:hover img, #wrap {{WRAPPER}} .latest-author:hover img, #wrap {{WRAPPER}} .au-avatar-box:hover .au-avatar img',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'author_img_border_hover',
				'label'    => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-author:hover img, #wrap {{WRAPPER}} .latest-author:hover img, #wrap {{WRAPPER}} .au-avatar-box:hover .au-avatar img',
			]
		);

		$this->add_control(
			'author_img_border_radius_hover',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .blog-author:hover img, #wrap {{WRAPPER}} .latest-author:hover img, #wrap {{WRAPPER}} .au-avatar-box:hover .au-avatar img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);			
				
		$this->add_control(
			'author_img_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author:hover img, #wrap {{WRAPPER}} .latest-author:hover img, #wrap {{WRAPPER}} .au-avatar-box:hover .au-avatar img' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'author_img_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-author:hover img, #wrap {{WRAPPER}} .latest-author:hover img, #wrap {{WRAPPER}} .au-avatar-box:hover .au-avatar img',
				]
		);

		$this->add_control(
			'author_img_padding_hover',
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .blog-author:hover img, #wrap {{WRAPPER}} .latest-author:hover img, #wrap {{WRAPPER}} .au-avatar-box:hover .au-avatar img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'author_img_margin_hover',
			[
				'label' 	  => __( 'Margin', 'deep' ),
				'type' 		  => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'  => [ 'px', 'em', '%' ],
				'selectors'   => [
					'#wrap {{WRAPPER}} .blog-author:hover img, #wrap {{WRAPPER}} .latest-author:hover img, #wrap {{WRAPPER}} .au-avatar-box:hover .au-avatar img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'author_img_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-author img, #wrap {{WRAPPER}} .latest-author img, #wrap {{WRAPPER}} .au-avatar-box .au-avatar img' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->end_controls_section();

		//  Social Buttons
		$this->start_controls_section(
			'section_social_style',
			[
				'label' => __( 'Social Button Style', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'social_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
    );
    
    $this->add_control(
			'social_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a' => 'display: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'social_style_tabs'
		);

		$this->start_controls_tab(
			'style_social_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'social_typography',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .blog-social-1 a',
			]
		);

		$this->add_control(
			'social_color',
			[
				'label' 		=> __( 'Color', 'deep' ), //heading
				'type' 			=> \Elementor\Controls_Manager::COLOR, //type
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-social-1 a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'social_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .blog-social-1 a',
			]
		);

		$this->add_control(
			'social_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'social_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-social-1 a',
				]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'social_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-social-1 a',
			]
		);
		
		$this->add_control(
			'social_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'social_padding', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'social_margin', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_social_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'social_typography_hover',
				'label' 	=> __( 'Social Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .blog-social-1 a:hover',
			]
		);

		$this->add_control(
			'social_color_hover', 
			[
				'label' 		=> __( 'Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .blog-social-1 a:hover i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'social_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .blog-social-1 a:hover',
			]
		);	

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'social_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .blog-social-1 a:hover',
			]
		);	
		
		$this->add_control(
			'social_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'social_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a:hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'social_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .blog-social-1 a:hover',
				]
		);

		$this->add_responsive_control(
			'social_padding_hover', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'social_margin_hover', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'social_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);
		
		$this->add_responsive_control(
			'social_width',
			[
				'label'	=> __( 'Width', 'deep' ),
				'type'	=> \Elementor\Controls_Manager::SLIDER,
				'range'	=> [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a' => 'width: {{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->add_responsive_control(
			'social_height',
			[
				'label' => __( 'Height', 'deep' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1 a' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'social_position',
			[
				'label' => __( 'Position', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					''  => __( 'Default', 'deep' ),
					'relative'  => __( 'Relative', 'deep' ),
					'absolute' => __( 'Absolute', 'deep' ),
					'fixed' => __( 'Fixed', 'deep' ),
					'static' => __( 'Static', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1' => 'position: {{VALUE}}',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'social_pos_top',
			[
				'label' => __( 'Top', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1' => 'top: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'social_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'social_pos_right',
			[
				'label' => __( 'Right', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1' => 'right: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'social_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'social_pos_bottom',
			[
				'label' => __( 'Bottom', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1' => 'bottom: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'social_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'social_pos_left',
			[
				'label' => __( 'Left', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .blog-social-1' => 'left: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'social_position'      => array( 'relative','absolute','fixed' ),
				),
			]
    );

		$this->end_controls_section();

			// Box Style
			$this->start_controls_section(
				'box_style',
				[
					'label' => __( 'Box Style', 'deep' ),
					'tab'   => Controls_Manager::TAB_STYLE,
				]
			);
	
			$this->add_control(
				'box_display',
				[
					'label'     => __( 'Display', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,		
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'inherit'      => __( 'Inherit', 'deep' ),
						'inline'       => __( 'inline', 'deep' ),
						'inline-block' => __( 'inline block', 'deep' ),
						'block'        => __( 'block', 'deep' ),
						'none'         => __( 'none', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-blogws-wrap' => 'display: {{VALUE}};',
					],
				]
			);
	
			$this->add_control(
				'box_overflow ',
				[
					'label'     => __( 'Overflow', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,		
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'inherit'   => __( 'inherit', 'deep' ),
						'scroll'    => __( 'scroll', 'deep' ),
						'hidden'    => __( 'hidden', 'deep' ),
						'auto' 		=> __( 'auto', 'deep' ),
						'visible'   => __( 'visible', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-blogws-wrap' => 'overflow: {{VALUE}};',
					],
				]
			);
	
			$this->start_controls_tabs(
				'box_style_tabs'
			);
	
			$this->start_controls_tab(
				'style_box_normal_tab',
				[
					'label' => __( 'Normal', 'deep' ),
				]
			);
			
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name'     => 'box_bg',
					'label'    => __( 'Background', 'deep' ),
					'types'    => [ 'classic' , 'gradient' ],
					'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap',
				]
			);

			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
					[
						'name'     => 'box_shadow',
						'label'    => __( 'Box Shadow', 'deep' ),
						'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap',
					]
			);
	
			$this->add_control(
				'box_opacity',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-blogws-wrap' => 'opacity: {{SIZE}};',
					],
				]
			);
			
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name'     => 'box_border',
					'label'    => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap',
				]
			);

			$this->add_control(
				'box_border_radius',
				[
					'label' 		=> __( 'Border Radius', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units'    => [ 'px', 'em', '%' ],
					'selectors'     => [
						'#wrap {{WRAPPER}} .wn-blogws-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);		
			
			$this->add_control(
				'box_padding',
				[
					'label' 		=> __( 'Padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units'    => [ 'px', 'em', '%' ],
					'selectors'     => [
						'#wrap {{WRAPPER}} .wn-blogws-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'box_margin',
				[
					'label' 		=> __( 'Margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units'    => [ 'px', 'em', '%' ],
					'selectors'     => [
						'#wrap {{WRAPPER}} .wn-blogws-wrap' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
		
			$this->end_controls_tab();
	
			$this->start_controls_tab(
				'style_box_hover_tab',
				[
					'label' => __( 'Hover', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name'     => 'box_bg_hover',
					'label'    => __( 'Background', 'deep' ),
					'types'    => [ 'classic' , 'gradient' ],
					'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap:hover',
				]
			);			
	
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
					[
						'name'     => 'box_shadow_hover',
						'label'    => __( 'Box Shadow', 'deep' ),
						'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap:hover',
					]
			);
	
			$this->add_control(
				'box_opacity_hover',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-blogws-wrap:hover' => 'opacity: {{SIZE}};',
					],
				]
			);
			
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name'     => 'box_border_hover',
					'label'    => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-blogws-wrap:hover',
				]
			);
	
			$this->add_control(
				'box_border_radius_hover',
				[
					'label' 		=> __( 'Border Radius', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units'    => [ 'px', 'em', '%' ],
					'selectors'     => [
						'#wrap {{WRAPPER}} .wn-blogws-wrap:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
				'box_padding_hover',
				[
					'label' 		=> __( 'Padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units'    => [ 'px', 'em', '%' ],
					'selectors'     => [
						'#wrap {{WRAPPER}} .wn-blogws-wrap:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_control(
				'box_margin_hover',
				[
					'label' 	  => __( 'Margin', 'deep' ),
					'type' 		  => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units'  => [ 'px', 'em', '%' ],
					'selectors'   => [
						'#wrap {{WRAPPER}} .wn-blogws-wrap:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->end_controls_tab();
			$this->end_controls_tabs();
	
			$this->add_control(
				'box_transition',
				[
					'label' => __( 'Transition', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-blogws-wrap' => 'transition: all {{SIZE}}s ease;',
					],
					'separator' => 'before',
				]
			);
	
			$this->end_controls_section();

		$this->start_controls_section(
			'custom_css_section_style',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'custom_css',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'type' => \Elementor\Controls_Manager::CODE,
				'language' => 'css',
				'rows' => 20,
				'show_label' => true,
			]
		);
		$this->end_controls_section();

	}

	/**
	 * Render Sermon Category widget output on the frontend.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings = $this->get_settings_for_display();
		
		ob_start();
		// Class & ID
		$shortcodeclass		= $settings['shortcodeclass'] ? $settings['shortcodeclass'] : '';
		$shortcodeid		= $settings['shortcodeid'] ? ' id="' . $settings['shortcodeid'] . '"' : '';

		$deep_options 		= deep_options();
		$p_count 			= '0';
		$paged 				= ( is_front_page() ) ? 'page' : 'paged' ;
		$deep_last_time 	= get_the_time(get_option( 'date_format' )); $deep_i=1; $deep_flag = false; //timeline
		$blog_sidebar 		= $deep_options['deep_sidebar_blog_options'] = isset($deep_options['deep_sidebar_blog_options']) ? $deep_options['deep_sidebar_blog_options'] : '' ;
		$sidebar			= $settings['sidebar'] ? $settings['sidebar'] : 'none';
		$orderby			=	$settings['orderby'];
		$loadmore_btn		=	$settings['loadmore_btn'];
		$count				=	$settings['count'];
		$category			=	$settings['category'];
		$type				=	$settings['type'];

		if ( $type == '11'|| $type == '12' || $type == '13' || $type == '14' || $type == '15' || $type == '18' || $type == '19' || $type == '20' || $type == '21' || $type == '22') {
			wp_enqueue_style( 'wn-deep-latest-from-blog21', DEEP_ASSETS_URL . 'css/frontend/latest-from-blog/latest-from-blog21.css' );
		}

		// orderby query args
		switch ( $orderby ) :
			case 'comment_count':
				$orderby = '&orderby=comment_count&order=DESC';
			break;

			case 'view_count':
				$orderby = '&meta_key=deep_views&orderby=meta_value_num&order=DESC';
			break;

			case 'social_score':
				if ( class_exists( 'SocialMetricsTracker' ) ) {
					$orderby ='&post_type=post&meta_key=socialcount_total&orderby=meta_value_num&order=DESC';
				}
			break;

			default:
				$orderby = '&orderby=date&order=DESC';
			break;
		endswitch;

		$args = 'post_type=post&paged='.get_query_var($paged).'&category_name='.$category.'&posts_per_page='.$count.$orderby.'';
		$query = new \WP_Query($args);
		if ($type == '16'){
			echo'<section id="main-content-pin"><div class="container"><div id="pin-content">';
		}elseif ($type == '17'){
			echo'<section class="wn-blog-ajax" id="main-content-timeline"><div class="container"><div id="tline-content">';
		}
		echo '<div class="wn-blogws-wrap ' . $shortcodeclass . '"  ' . $shortcodeid . '>';
		// left sidebar
		if ( $sidebar == 'left' || $sidebar == 'both' ) {
			echo '<aside class="col-md-3 sidebar leftside ' . $blog_sidebar . ' ">';
				if( is_active_sidebar( 'Left Sidebar' ) ) dynamic_sidebar( 'Left Sidebar' );
			echo '</aside>';
		}

		if ( $sidebar == 'left' || $sidebar == 'right' ) {
			echo '<div class="col-md-9 cntt-w">';
		} elseif ( $sidebar == 'both' ) {
			echo '<div class="col-md-6 cntt-w">';
		}

		if ($query ->have_posts()) :
			if ($type == '3')
				echo '<div class="row">';
		while ($query -> have_posts()) : $query -> the_post();
			if ( $type == '2' ) {

				echo '<div class="blg-def-list wn-blog-ajax">';					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type2.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type2');
					}
				echo '</div>';

			} elseif ( $type == '4' ) {

				if( $p_count == '0' ) {
					echo '<div class="blg-def-full wn-blog-ajax">';						
						if ( defined( 'DEEP_HANDLE' ) ) {
							include DEEP_INCLUDES_DIR . 'templates/loops/blogloop.php';
						} else {
							get_template_part( 'inc/templates/loops/blogloop');
						}
					echo '</div>';

				} else {
					echo '<div class="blg-def-list wn-blog-ajax">';						
						if ( defined( 'DEEP_HANDLE' ) ) {
							include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type2.php';
						} else {
							get_template_part( 'inc/templates/loops/blogloop-type2');
						}
					echo '</div>';

				}

				$p_count++;

			} elseif ( $type == '3' ) {
					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type3.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type3');
					}

			} elseif ( $type == '5' ) {

				if ( $p_count == '0' ) {

					echo '<div class="blg-def-full wn-blog-ajax">';						
						if ( defined( 'DEEP_HANDLE' ) ) {
							include DEEP_INCLUDES_DIR . 'templates/loops/blogloop.php';
						} else {
							get_template_part( 'inc/templates/loops/blogloop');
						}
					echo '</div>';
					echo '<div class="row">';

				} else {
					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type3.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type3');
					}

				}

				$p_count++;

			} elseif ( $type == '16' ) {

				echo '<div class="wn-blog-ajax">';				
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-masonry.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-masonry' );
					}
				echo '</div>';

			} elseif (  $type == '17' ) {
							global $post;
							$post_id = $post->ID;
							$post_format = get_post_format($post_id);
							$content = get_the_content();
							if( !$post_format ) $post_format = 'standard';
							if(($deep_last_time != date(' F Y',strtotime($post->post_date)) ) || $deep_i==1){
								$deep_last_time = date(' F Y',strtotime($post->post_date));
								echo '<div class="tline-topdate">'.  date(' F Y',strtotime($post->post_date)) .'</div>';
								if( $deep_i>1 ) $deep_flag = true;
							} ?>
								<article id="post-<?php the_ID(); ?>"  class="tline-box"> <span class="tline-row-<?php if(($deep_i%2)==0) echo 'r'; else echo 'l'; ?>"></span>
									<div class="tline-author-box">
										<h6 class="tline-author">
											<?php the_author_posts_link(); ?>
										</h6>
										<?php echo get_avatar( get_the_author_meta( 'user_email' ), 28 ); ?>
										<h6 class="tline-date"><?php echo get_the_date();?></h6>
									</div>
									<div class="tline-content-wrap">
										<div class="tline-ecxt col-md-7">
											<?php if(  $deep_options['deep_blog_meta_category_enable'] ):?>
											<h6 class="blog-cat-tline" style="background:<?php echo deep_category_color(); ?>;"> <?php the_category('- ') ?></h6>
											<?php endif; ?>
											<?php
											if($deep_options['deep_blog_posttitle_enable'] ) {
												if( ('aside' != $post_format ) && ('quote' != $post_format)  ) {
													if( 'link' == $post_format ) {
														preg_match('/\b(?:(?:https?|ftp):\/\/|www\.)[-a-z0-9+&@#\/%?=~_|!:,.;]*[-a-z0-9+&@#\/%=~_|]/i', $content,$matches);
														$content = preg_replace('/\b(?:(?:https?|ftp):\/\/|www\.)[-a-z0-9+&@#\/%?=~_|!:,.;]*[-a-z0-9+&@#\/%=~_|]/i','', $content,1);
														$link ='';
														if(isset($matches) && is_array($matches))
															$link = $matches[0];
														?>
														<h4><a href="<?php echo esc_url($link); ?>"><?php the_title(); ?></a></h4>
														<?php
													}else{
														?>
														<h4><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>
														<p class="blog-tline-excerpt">
															<?php echo deep_excerpt( ( $deep_options['deep_blog_excerpt_list'] ) ? $deep_options['deep_blog_excerpt_list'] : 19 ); ?>
														</p>
														<?php } }
												}
												if( $post_format == ('quote') || $post_format == 'aside' ) {
													echo '<blockquote>';
														echo deep_excerpt(31);
													echo '</blockquote>';
												}
												?>

													</div>
									<div class="tline-rigth-side col-md-5"> <?php
										$thumbnail_url = get_the_post_thumbnail_url( $post_id );
										$thumbnail_id  = get_post_thumbnail_id( $post_id );

										if( !empty( $thumbnail_url ) ) {
											// if main class not exist get it
											if ( !class_exists( 'Wn_Img_Maniuplate' ) ) {
												require_once DEEP_CORE_DIR . 'helper-classes/class_webnus_manuplate.php';
											}
											$image = new \Wn_Img_Maniuplate; // instance from settor class
											$thumbnail_url = $image->m_image( $thumbnail_id, $thumbnail_url , '390' , '297' ); // set required and get result
										}

										if( $deep_options['deep_blog_featuredimage_enable'] ){

											$meta_video = rwmb_meta( 'deep_featured_video_meta' );

											if($post_format  == 'video' || $post_format == 'audio') {

												$pattern = '\\[' . '(\\[?)' . "(video|audio)" . '(?![\\w-])' . '(' . '[^\\]\\/]*' . '(?:' . '\\/(?!\\])' . '[^\\]\\/]*' . ')*?' . ')' . '(?:' . '(\\/)' . '\\]' . '|' . '\\]' . '(?:' . '(' . '[^\\[]*+' . '(?:' . '\\[(?!\\/\\2\\])' . '[^\\[]*+' . ')*+' . ')' . '\\[\\/\\2\\]' . ')?' . ')' . '(\\]?)';
												preg_match( '/' . $pattern . '/s', $post->post_content, $matches );

												if( ( is_array( $matches) ) && ( isset( $matches[3] ) ) && (  ( $matches[2] == 'video' ) || ( 'audio'  == $post_format ) ) && ( isset($matches[2] ) ) ) {
													$video = $matches[0];
													echo do_shortcode($video);
													$content = preg_replace('/'.$pattern.'/s', '', $content);

													} elseif( (!empty( $meta_video )) ) {

														echo do_shortcode($meta_video);

													}
											} else
											if( 'gallery'  == $post_format){
												$pattern = '\\[' . '(\\[?)' . "(gallery)" . '(?![\\w-])' . '(' . '[^\\]\\/]*' . '(?:' . '\\/(?!\\])' . '[^\\]\\/]*' . ')*?' . ')' . '(?:' . '(\\/)' . '\\]' . '|' . '\\]' . '(?:' . '(' . '[^\\[]*+' . '(?:' . '\\[(?!\\/\\2\\])' . '[^\\[]*+' . ')*+' . ')' . '\\[\\/\\2\\]' . ')?' . ')' . '(\\]?)';
												preg_match('/'.$pattern.'/s', $post->post_content, $matches);
												if( (is_array($matches)) && (isset($matches[3])) && ($matches[2] == 'gallery') && (isset($matches[2]))) {
													$ids = (shortcode_parse_atts($matches[3]));
													if(is_array($ids) && isset($ids['ids']))
														$ids = $ids['ids'];
														$galley_url = array();
														$galley_id = explode(",",$ids); 

														?>						

														<div class="post-gallery-format">
															<div class="gl-img owl-carousel owl-theme">
																<?php

																for ($i=0; $i < sizeof($galley_id); $i++) {

																	// echo wp_get_attachment_image( $galley_id[$i], 'full' );
																	if( !empty( $galley_id[$i] ) ) {

																		// if main class not exist get it
																		if ( !class_exists( 'Wn_Img_Maniuplate' ) ) {
																			require_once DEEP_CORE_DIR . 'helper-classes/class_webnus_manuplate.php';
																		}									
																		$thumbnail_url = $image->m_image( $galley_id[$i], wp_get_attachment_url( $galley_id[$i] ) , '385' , '293' ); // set required and get result

																		echo '<img src="' . esc_url($thumbnail_url) . '" alt="' . get_the_title() . '">';

																	}

																} ?>											
															</div>													
														</div>	
														<?php															
												}
											} else {
												if ( $thumbnail_url ) { ?>
													<a href="<?php the_permalink(); ?>">
														<img src="<?php echo '' . $thumbnail_url ?>" alt="<?php the_title(); ?>" >
													</a>
												<?php }
											}
										} ?>
									</div>

									<div class="tline-footer"> <?php
										if( $deep_options['deep_blog_meta_comments_enable'] ) { ?>
											<div class="tline-comment">
												<i class="wn-fa wn-fa-comment"></i>
												<?php comments_number( ); ?>
											</div> <?php
										}
										if( $deep_options['deep_blog_social_share'] ) {
											deep_social_share( $post_id );
										}
										?>
									</div>
								</div>
							</article>
							<?php $deep_i++;
			} elseif ( $type == '6' ) { // personal blog

				echo '<div class="blg-personal-full blgtyp10 wn-blog-ajax">';						
						if ( defined( 'DEEP_HANDLE' ) ) {
							include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type1.php';
						} else {
							get_template_part( 'inc/templates/loops/blogloop-type1');
						}
				echo '</div>';

			} elseif ( $type == '7' ) { // personal blog
				echo '<div class="blg-personal-list wn-blog-ajax">';					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type5.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type5');
					}
				echo '</div>';
			} elseif ( $type == '9' ) { // personal blog

					if( $p_count == '0' ) {
						echo '<div class="blg-personal-full blgfltl wn-blog-ajax">';							
							if ( defined( 'DEEP_HANDLE' ) ) {
								include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type1.php';
							} else {
								get_template_part( 'inc/templates/loops/blogloop-type1');
							}
						echo '</div>';

					} else {

						echo '<div class="blg-personal-list blgfltl wn-blog-ajax">';							
							if ( defined( 'DEEP_HANDLE' ) ) {
								include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type5.php';
							} else {
								get_template_part( 'inc/templates/loops/blogloop-type5');
							}
						echo '</div>';

					}

					$p_count++;

			} elseif ( $type == '8' ) { // personal blog

				echo '<div class="blg-personal-grid col-md-6 blg-typ3 blgtyp10 wn-blog-ajax">';					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type7.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type7');
					}
				echo '</div>';

			} elseif ( $type == '10' ) { // personal blog


				if( $p_count == '0' ) {

					echo '<div class="blg-personal-full blgtyp10 wn-blog-ajax">';					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type1.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type1');
					}
					echo '</div>';

				} else {

					echo '<div class="blg-personal-grid wn-blog-ajax col-md-6 blg-typ3 blgtyp10">';					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type7.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type7');
					}
					echo '</div>';

				}

				$p_count++;


			} elseif ( $type == '11' ) { // Magazine
				echo '<div class="blg-magazine-full blgtyp11 wn-blog-ajax">';
				if( $p_count == '0' ) {					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type6.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type6');
					}
				}
				echo '</div>';
			} elseif ( $type == '18' ) { // Magazine
				echo '<div class="blg-minimal-full blgtyp18 wn-blog-ajax">';
				if( $p_count == '0' ) {											
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type9.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type9');
					}
				}					
				echo '</div>';
			} elseif ( $type == '12' ) { // Magazine
				echo '<div class="blg-magazine-list wn-blog-ajax">';				
				if ( defined( 'DEEP_HANDLE' ) ) {
					include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type4.php';
				} else {
					get_template_part( 'inc/templates/loops/blogloop-type4');
				}
				echo '</div>';
			} elseif ( $type == '19' ) { // Magazine
				echo '<div class="blg-minimal-list wn-blog-ajax">';				
				if ( defined( 'DEEP_HANDLE' ) ) {
					include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type4.php';
				} else {
					get_template_part( 'inc/templates/loops/blogloop-type4');
				}
				echo '</div>';
			} elseif ( $type == '14' ) { // Magazine
				if( $p_count == '0' ) {
					echo '<div class="blg-magazine-full blgtyp11 wn-blog-ajax">';					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type6.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type6');
					}
					echo '</div>';
				} else {
					echo '<div class="blg-magazine-list blgtyp11 wn-blog-ajax">';					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type4.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type4');
					}
					echo '</div>';
				}
				$p_count++;
			}  elseif ( $type == '21' ) { // Magazine			
					if( $p_count == '0' ) {
						echo '<div class="blg-minimal-full blgtyp18 wn-blog-ajax">';						
						if ( defined( 'DEEP_HANDLE' ) ) {
							include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type9.php';
						} else {
							get_template_part( 'inc/templates/loops/blogloop-type9');
						}
						echo '</div>';
					} else {
						echo '<div class="blg-minimal-list blgtyp18 wn-blog-ajax">';						
						if ( defined( 'DEEP_HANDLE' ) ) {
							include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type4.php';
						} else {
							get_template_part( 'inc/templates/loops/blogloop-type4');
						}
						echo '</div>';
					}
					$p_count++;

			} elseif ( $type == '13' ) { // Magazine
				echo '<div class="blg-magazine-grid blgtyp11 col-md-6 wn-blog-ajax">';					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type8.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type8');
					}
				echo '</div>';
			} elseif ( $type == '20' ) { // Magazine
				echo '<div class="blg-minimal-grid blgtyp11 col-md-6 wn-blog-ajax">';					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type8.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type8');
					}
				echo '</div>';
			} elseif ( $type == '15' ) { // Magazine
				$classes = $p_count == '0' ? 'blg-magazine-full blgtyp11 wn-blog-ajax' : 'blg-magazine-grid wn-blog-ajax col-md-6 blg-typ3 blgtyp11';
				echo '<div class="' . esc_attr( $classes ) . '">';
				if( $p_count == '0' ) {					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type6.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type6');
					}
				} else {					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type8.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type8');
					}
				}
				$p_count++;
				echo '</div>';
			} elseif ( $type == '22' ) { // Magazine
				$classes = $p_count == '0' ? 'blg-minimal-full blgtyp18 wn-blog-ajax' : 'blg-minimal-grid wn-blog-ajax col-md-6 blg-typ3 blgtyp18';
				echo '<div class="' . esc_attr( $classes ) . '">';
				if( $p_count == '0' ) {					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type9.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type9');
					}
				} else {					
					if ( defined( 'DEEP_HANDLE' ) ) {
						include DEEP_INCLUDES_DIR . 'templates/loops/blogloop-type8.php';
					} else {
						get_template_part( 'inc/templates/loops/blogloop-type8');
					}
				}
				$p_count++;
				echo '</div>';
			} else {
				echo '<div class="wn-blog-ajax blg-def-full">';				
				if ( defined( 'DEEP_HANDLE' ) ) {
					include DEEP_INCLUDES_DIR . 'templates/loops/blogloop.php';
				} else {
					get_template_part( 'inc/templates/loops/blogloop');
				}
				echo '</div>';
			}
		endwhile;
		if( $type == '3' || $type == '5' )
			echo '</div>';

		elseif( $type == '17' ) // for timeline
			echo'<div class="tline-topdate enddte">'. get_the_time(get_option( 'date_format' )) .'</div></div></div>';
		endif;

		if ( $type == '17' ) {
			echo '</section>';
		}

		/**
		 * end masonry
		 *
		*/
		if ( $type == '16' ) {
			echo '</div></div></section>';
		}

		/**
		 * page navi
		 * @author Webnus
		 * @version 1.0.0
		 *
		*/
		if( function_exists('wp_pagenavi') ) {
			if ($loadmore_btn != 'yes') {

				if ( $type == '11' || $type == '12' || $type == '13' || $type == '14' ) {
					echo '<div class="pagination-blgtype4">';
				}
				wp_pagenavi( array( 'query' => $query ) );

				if ( $type == '11' || $type == '12' || $type == '13' || $type == '14' ) {
					echo '</div>';
				}
			}
		}

		/**
		 * loar more button
		 *
		*/
		if ( $loadmore_btn == 'yes' ) {
			global $wp;
			$posts_per_page		= $query->query_vars[ 'posts_per_page' ];
			$found_posts		= $query->found_posts;
			$max_num_pages		= $query->max_num_pages;
			$current_page_num	= $query->query[ 'paged' ];
			$current_page_url	= home_url( $wp->request );
			?>
			<div
				class="wn-loadmore-ajax"
				data-site-url="<?php echo '' . $current_page_url; ?>"
				data-current-page="<?php echo '' . $current_page_num; ?>"
				data-max-page-num="<?php echo '' . $max_num_pages; ?>"
				data-total="<?php echo '' . $posts_per_page; ?>"
				data-post-pre-page="<?php echo '' . $found_posts; ?>"
				data-no-more-post="<?php _e( 'NO MORE POST', 'deep' ) ?>"
			>
				<a href="#"><?php _e( 'LOAD MORE', 'deep' ); ?></a>
			</div> <?php
		}

		if ( $sidebar != 'none' ) {
			echo '</div>'; // end col-md-9 or col-md-6
		}


		// right sidebar
		if ( $sidebar == 'right' || $sidebar == 'both' ) {
			echo '<aside class="col-md-3 sidebar rightside ' . $blog_sidebar . ' ">';
				if( is_active_sidebar( 'Right Sidebar' ) ) dynamic_sidebar( 'Right Sidebar' );
			echo '</aside>';
		}
		echo '</div>'; // end wn-blogws-wrap
		$out = ob_get_contents();
		ob_end_clean();
		wp_reset_postdata();


		$custom_css = $settings['custom_css'];

		if ( $custom_css != '' ) {
			echo '<style>'. $custom_css .'</style>';
		}
		echo $out;



	}

}
