<?php
namespace Elementor;
class Webnus_Element_Widgets_CategoryTab extends \Elementor\Widget_Base {

	/**
	 * Retrieve Info Box widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {

		return 'category_tab';

	}

	/**
	 * Retrieve Info Box widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {

		return esc_html__( 'Webnus Category Tab', 'deep' );

	}

	/**
	 * Retrieve Info Box widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {

		return 'ti-layout-tab-v';

	}

	/**
	 * Set widget category.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget category.
	 */
	public function get_categories() {

		return [ 'webnus' ];

	}

	/**
	 * enqueue CSS
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_style_depends() {

		return [ 'wn-deep-category-tab' ];

	}

	/**
	 * enqueue JS
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_script_depends() {

		return [ 'cat-tab' ];

	}


	/**
	 * Register Info Box widget controls.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$categories = array();
		$categories = get_categories();
		$category_slug_array = array('');
		$category_name_array = array('');
		foreach( $categories as $category ) {
			$category_slug_array[] = $category->name;
			$category_name_array[] = $category->slug;
		}

		$category_array  = array_combine($category_name_array, $category_slug_array);

        // Content Tab
		$this->start_controls_section(
			'content_sectiona',
			[
				'label' => esc_html__( 'General Options', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
		);

		$this->add_control(
			'param_category',
			[
				'label' 	=> esc_html__( 'Choose Categories', 'deep' ),
				'type' 		=> \Elementor\Controls_Manager::SELECT2,
				'multiple' 	=> true,
				'options' 	=> $category_array,
			]
		);

		$this->add_control(
			'sort_order', //param_name
			[
				'label' 	=> esc_html__( 'Sort order', 'deep' ), //heading
				'type' 		=> \Elementor\Controls_Manager::SELECT, //type
				'default' 	=> 'date',
				'options' 	=> [ //value
					'date'  		=> esc_html__( 'Date', 'deep' ),
					'title' 		=> esc_html__( 'Title', 'deep' ),
					'comment_count' => esc_html__( 'Popular Post', 'deep' ),
					'latest' 		=> esc_html__( 'Recent Posts', 'deep' ),
					'rand' 			=> esc_html__( 'Random Post', 'deep' ),
					'modified' 		=> esc_html__( 'Last Modified Post', 'deep' ),
				],
			]
		);

		$this->add_control(
			'p_cat', //param_name
			[
				'label' 		=> __( 'Post Category', 'deep' ), //heading
				'type' 			=> \Elementor\Controls_Manager::SWITCHER, //type
				'label_on' 		=> __( 'Show', 'deep' ),
				'label_off' 	=> __( 'Hide', 'deep' ),
				'return_value' 	=> 'show',
			]
		);

		$this->add_control(
			'p_date', //param_name
			[
				'label' 		=> __( 'Post Date', 'deep' ), //heading
				'type' 			=> \Elementor\Controls_Manager::SWITCHER, //type
				'label_on' 		=> __( 'Show', 'deep' ),
				'label_off' 	=> __( 'Hide', 'deep' ),
				'return_value' 	=> 'show',
			]
		);


        $this->end_controls_section();

		// Class & ID Tab
		$this->start_controls_section(
			'classid_section',
			[
				'label' => esc_html__( 'Class & ID', 'deep' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'shortcodeclass',
			[
				'label'	=> esc_html__( 'Extra Class', 'deep' ),
				'type'	=> Controls_Manager::TEXT,
			]
		);

		$this->add_control(
			'shortcodeid',
			[
				'label'	=> esc_html__( 'ID', 'deep' ),
				'type'	=> Controls_Manager::TEXT,
			]
		);

		$this->end_controls_section();
		// Wrap Style
		$this->start_controls_section(
			'section_wrap_style',
			[
				'label' => __( 'Wrap Items', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		
		$this->add_control(
			'wrap_text_align',
			[
				'label'     => __( 'Text align', 'deep' ),
				'type'      => \Elementor\Controls_Manager::CHOOSE,
				'options'   => [
					'left'   => [
						'title' => __( 'Left', 'deep' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'deep' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'  => [
						'title' => __( 'Right', 'deep' ),
						'icon'  => 'fa fa-align-right',
					],
				],
				'toggle'    => true,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab' => 'text-align: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'wrap_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_control(
			'wrap_display',
			[
				'label'     => __( 'Display', 'deep' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => [
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab' => 'display: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'wrap_style_tabs'
		);

		$this->start_controls_tab(
			'style_wrap_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'wrap_typography',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-category-tab',
			]
		);

		$this->add_control(
			'wrap_color',
			[
				'label' 		=> __( 'color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-category-tab' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'wrap_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' ],
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab',
			]
		);
		
		$this->add_control(
			'wrap_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wrap_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab',
			]
		);

		$this->add_control(
			'wrap_border_radius',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'wrap_padding',
			[
				'label' 		=> __( 'padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'wrap_margin',
			[
				'label' 		=> __( 'margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_wrap_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'wrap_typography_hover',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-category-tab:hover',
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'wrap_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' ],
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab:hover',
			]
		);
		
		$this->add_control(
			'wrap_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab:hover' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'wrap_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab:hover',
			]
		);

		$this->add_control(
			'wrap_border_radius_hover',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'wrap_padding_hover',
			[
				'label' 		=> __( 'padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'wrap_margin_hover',
			[
				'label' 		=> __( 'margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'wrap_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'wrap_content_heading',
			[
				'label' => __( 'Content Background', 'deep' ),
				'type' => \Elementor\Controls_Manager::HEADING,
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'wrap_bg_content',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' ],
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content',
			]
		);

		$this->end_controls_section();

		// Item Style
		$this->start_controls_section(
			'section_items_style',
			[
				'label' => __( 'Tab Items', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		
		$this->add_control(
			'items_text_align',
			[
				'label'     => __( 'Text align', 'deep' ),
				'type'      => \Elementor\Controls_Manager::CHOOSE,
				'options'   => [
					'left'   => [
						'title' => __( 'Left', 'deep' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'deep' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'  => [
						'title' => __( 'Right', 'deep' ),
						'icon'  => 'fa fa-align-right',
					],
				],
				'toggle'    => true,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li' => 'text-align: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'item_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_control(
			'items_display',
			[
				'label'     => __( 'Display', 'deep' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'options'   => [
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li' => 'display: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'item_style_tabs'
		);

		$this->start_controls_tab(
			'style_item_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'items_typography',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-category-wrap li a',
			]
		);

		$this->add_control(
			'items_color',
			[
				'label' 		=> __( 'color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-category-wrap li a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'items_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' ],
				'selector' => '#wrap {{WRAPPER}} .wn-category-wrap li a',
			]
		);
		
		$this->add_control(
			'items_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li a' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'items_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-category-wrap li a',
			]
		);

		$this->add_control(
			'items_border_radius',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'items_padding',
			[
				'label' 		=> __( 'padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'items_margin',
			[
				'label' 		=> __( 'margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_item_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'items_typography_hover',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-category-wrap li a:hover',
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'items_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' ],
				'selector' => '#wrap {{WRAPPER}} .wn-category-wrap li a:hover',
			]
		);
		
		$this->add_control(
			'items_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li a:hover' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'items_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-category-wrap li a:hover',
			]
		);

		$this->add_control(
			'items_border_radius_hover',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'items_padding_hover',
			[
				'label' 		=> __( 'padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li a:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'items_margin_hover',
			[
				'label' 		=> __( 'margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li a:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'item_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap li a' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);
		
		$this->end_controls_section();

			// Title Style
			$this->start_controls_section(
				'section_title_style',
				[
					'label' => __( 'Title style', 'deep' ),
					'tab' => Controls_Manager::TAB_STYLE,
				]
			);
	
			$this->add_control(
				'title_text_align',
				[
					'label'     => __( 'Text align', 'deep' ),
					'type'      => \Elementor\Controls_Manager::CHOOSE,
					'options'   => [
						'left'   => [
							'title' => __( 'Left', 'deep' ),
							'icon'  => 'fa fa-align-left',
						],
						'center' => [
							'title' => __( 'Center', 'deep' ),
							'icon'  => 'fa fa-align-center',
						],
						'right'  => [
							'title' => __( 'Right', 'deep' ),
							'icon'  => 'fa fa-align-right',
						],
					],				
					'toggle'    => true,
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'text-align: {{VALUE}}',
					],
				]
			);
	
			$this->add_responsive_control(
				'title_float',
				[
					'label'     => __( 'Float', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,		
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'right'      => __( 'Right', 'deep' ),
						'left'       => __( 'Left', 'deep' ),
						'unset' => __( 'Unset', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'float: {{VALUE}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
			
			$this->add_control(
				'title_display',
				[
					'label'     => __( 'Display', 'deep' ), 
					'type'      => \Elementor\Controls_Manager::SELECT,		
					'options'   => [ 
						''      => __( 'Default', 'deep' ),
						'inherit'      => __( 'Inherit', 'deep' ),
						'inline'       => __( 'inline', 'deep' ),
						'inline-block' => __( 'inline block', 'deep' ),
						'block'        => __( 'block', 'deep' ),
						'none'         => __( 'none', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5' => 'display: {{VALUE}};',
					],
				]
			);
	
			$this->start_controls_tabs(
				'title_style_tabs'
			);
	
			$this->start_controls_tab(
				'style_title_normal_tab',
				[
					'label' => __( 'Normal', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography',
					'label' 	=> __( 'Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .wn-tab-cat-content h5 a',
				]
			);
	
			$this->add_control(
				'title_color',
				[
					'label' 		=> __( 'Color', 'deep' ), //heading
					'type' 			=> \Elementor\Controls_Manager::COLOR, //type
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' => 'title_bg',
					'label' => __( 'Background', 'deep' ),
					'types' => [ 'classic' , 'gradiant' ],
					'selector' => '#wrap {{WRAPPER}} .wn-tab-cat-content h5 a',
				]
			);
	
			$this->add_control(
				'title_opacity',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'opacity: {{SIZE}};',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
					[
						'name'     => 'title_box_shadow',
						'label'    => __( 'Box Shadow', 'deep' ),
						'selector' => '#wrap {{WRAPPER}} .wn-tab-cat-content h5 a',
					]
			);
			
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'title_border',
					'label' => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-tab-cat-content h5 a',
				]
			);
			
			$this->add_control(
				'title_border_radius', 
				[
					'label' 		=> __( 'Border Radius', 'deep' ), 
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
	
			$this->add_responsive_control(
				'title_padding', 
				[
					'label' 		=> __( 'Title padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
	
			$this->add_responsive_control(
				'title_margin', 
				[
					'label' 		=> __( 'Title margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);	
	
			$this->end_controls_tab();
	
			$this->start_controls_tab(
				'style_title_hover_tab',
				[
					'label' => __( 'Hover', 'deep' ),
				]
			);
	
			$this->add_group_control(
				Group_Control_Typography::get_type(),
				[
					'name' 		=> 'title_typography_hover',
					'label' 	=> __( 'Title Typography', 'deep' ),
					'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
					'selector' 	=> '#wrap {{WRAPPER}} .wn-tab-cat-content h5 a:hover',
				]
			);
	
			$this->add_control(
				'title_color_hover', 
				[
					'label' 		=> __( 'Title color', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::COLOR,
					'selectors' 	=> [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a:hover' => 'color: {{VALUE}}',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Background::get_type(),
				[
					'name' => 'title_bg_hover',
					'label' => __( 'Background', 'deep' ),
					'types' => [ 'classic' , 'gradiant' ],
					'selector' => '#wrap {{WRAPPER}} .wn-tab-cat-content h5 a:hover',
				]
			);	
	
			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'title_border_hover',
					'label' => __( 'Border', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-tab-cat-content h5 a:hover',
				]
			);	
			
			$this->add_control(
				'title_border_radius_hover', 
				[
					'label' 		=> __( 'Border Radius', 'deep' ), 
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);
			
			$this->add_control(
				'title_opacity_hover',
				[
					'label' => __( 'Opacity', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1,
							'step' => 0.1,
						],
					],			
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a:hover' => 'opacity: {{SIZE}};',
					],
				]
			);
	
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
					[
						'name'     => 'title_box_shadow_hover',
						'label'    => __( 'Box Shadow', 'deep' ),
						'selector' => '#wrap {{WRAPPER}} .wn-tab-cat-content h5 a:hover',
					]
			);
	
			$this->add_responsive_control(
				'title_padding_hover', 
				[
					'label' 		=> __( 'Title padding', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
	
			$this->add_responsive_control(
				'title_margin_hover', 
				[
					'label' 		=> __( 'Title margin', 'deep' ),
					'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em', '%' ],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);	
	
			$this->end_controls_tab();
			$this->end_controls_tabs();
	
			$this->add_control(
				'title_transition',
				[
					'label' => __( 'Transition', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'transition: all {{SIZE}}s ease;',
					],
					'separator' => 'before',
				]
			);
			
			$this->add_responsive_control(
				'title_position',
				[
					'label' => __( 'Position', 'deep' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => '',
					'options' => [
						''  => __( 'Default', 'deep' ),
						'relative'  => __( 'Relative', 'deep' ),
						'absolute' => __( 'Absolute', 'deep' ),
						'fixed' => __( 'Fixed', 'deep' ),
						'static' => __( 'Static', 'deep' ),
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'position: {{VALUE}}',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
				]
			);
			
			$this->add_responsive_control(
				'title_pos_top',
				[
					'label' => __( 'Top', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'top: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'title_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'title_pos_right',
				[
					'label' => __( 'Right', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'right: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'title_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'title_pos_bottom',
				[
					'label' => __( 'Bottom', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'bottom: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'title_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->add_responsive_control(
				'title_pos_left',
				[
					'label' => __( 'Left', 'deep' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px', '%' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 1000,
							'step' => 5,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => '',
					],
					'selectors' => [
						'#wrap {{WRAPPER}} .wn-tab-cat-content h5 a' => 'left: {{SIZE}}{{UNIT}};',
					],
					'devices' => [ 'desktop', 'tablet', 'mobile' ],
					'condition'     => array(
						'title_position'      => array( 'relative','absolute','fixed' ),
					),
				]
			);
	
			$this->end_controls_section();
			
				// Category Styles
		$this->start_controls_section(
			'section_category_style',
			[
				'label' => __( 'Category Style', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'category_align',
			[
				'label' => __( 'Text Alignment', 'deep' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'deep' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'deep' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'deep' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'toggle' => true,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta' => 'text-align: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'category_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'category_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta' => 'display: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->start_controls_tabs(
			'category_style_tabs'
		);

		$this->start_controls_tab(
			'style_category_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'category_typography',
				'label' 	=> __( 'Category Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta a',
			]
		);

		$this->add_control(
			'category_color', 
			[
				'label' 		=> __( 'Category color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'category_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'category_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta',
			]
		);
		
		$this->add_control(
			'category_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'category_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'category_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta',
				]
		);

		$this->add_responsive_control(
			'category_padding', 
			[
				'label' 		=> __( 'Category padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'category_margin', 
			[
				'label' 		=> __( 'Category margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_category_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'category_typography_hover',
				'label' 	=> __( 'Category Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta:hover a',
			]
		);

		$this->add_control(
			'category_color_hover', 
			[
				'label' 		=> __( 'Category color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta:hover a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'category_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta:hover',
			]
		);	

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'category_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta:hover',
			]
		);
		
		$this->add_control(
			'category_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'category_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta:hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'category_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta:hover',
				]
		);

		$this->add_responsive_control(
			'category_padding_hover', 
			[
				'label' 		=> __( 'Category padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'category_margin_hover', 
			[
				'label' 		=> __( 'Category margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'category_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta, #wrap {{WRAPPER}} .wn-category-tab .wn-category .wn-tab-cat-content .wn-category-meta a' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
    );

		$this->end_controls_section();

			// Date Style
		$this->start_controls_section(
			'section_dates_style',
			[
				'label' => __( 'Dates Style', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'dates_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
    );

		$this->add_responsive_control(
			'dates_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date' => 'display: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->start_controls_tabs(
			'dates_style_tabs'
		);

		$this->start_controls_tab(
			'style_dates_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'dates_typography',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date',
			]
		);

		$this->add_control(
			'dates_color', 
			[
				'label' 		=> __( 'Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'dates_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'dates_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date',
			]
		);
		
		$this->add_control(
			'dates_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'dates_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'dates_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date',
				]
		);

		$this->add_responsive_control(
			'dates_padding', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'dates_margin', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_dates_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'dates_typography_hover',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .wn-category-tab:hover .wn-tab-cat-content .wn-category-date',
			]
		);

		$this->add_control(
			'dates_color_hover', 
			[
				'label' 		=> __( 'Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-category-tab:hover .wn-tab-cat-content .wn-category-date' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'dates_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' , 'gradiant' ],
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab:hover .wn-tab-cat-content .wn-category-date',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'dates_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-category-tab:hover .wn-tab-cat-content .wn-category-date',
			]
		);
		
		$this->add_control(
			'dates_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab:hover .wn-tab-cat-content .wn-category-date' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'dates_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab:hover .wn-tab-cat-content .wn-category-date' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'dates_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-category-tab:hover .wn-tab-cat-content .wn-category-date',
				]
		);

		$this->add_responsive_control(
			'dates_padding_hover', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab:hover .wn-tab-cat-content .wn-category-date' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'dates_margin_hover', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab:hover .wn-tab-cat-content .wn-category-date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'dates_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->add_control(
			'icon_dates_heading',
			[
				'label' => __( 'Icon Styles', 'deep' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'icon_dates_size',
			[
				'label' 		=> __( 'Size', 'deep' ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' 	=> [ 'px', '%' ],
				'range' 		=> [
					'px' 		=> [
						'min' 		=> 0,
						'max' 		=> 200,
						'step' 		=> 1,
					],
					'%' 		=> [
						'min' 		=> 0,
						'max' 		=> 100,
					],
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date i' => 'font-size: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'icon_dates_color', 
			[
				'label' 		=> __( 'Icon Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-category-tab .wn-tab-cat-content .wn-category-date i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'color_icon_dates_hover', 
			[
				'label' 		=> __( 'Icon Color Hover', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .wn-category-tab:hover .wn-tab-cat-content .wn-category-date i' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();
		
		$this->end_controls_section();

		// Box Style
		$this->start_controls_section(
			'box_style',
			[
				'label' => __( 'Box Style', 'deep' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'box_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap' => 'display: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'box_overflow ',
			[
				'label'     => __( 'Overflow', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'   => __( 'inherit', 'deep' ),
					'scroll'    => __( 'scroll', 'deep' ),
					'hidden'    => __( 'hidden', 'deep' ),
					'auto' 		=> __( 'auto', 'deep' ),
					'visible'   => __( 'visible', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap' => 'overflow: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'box_style_tabs'
		);

		$this->start_controls_tab(
			'style_box_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'box_bg',
				'label'    => __( 'Background', 'deep' ),
				'types'    => [ 'classic' , 'gradient' ],
				'selector' => '#wrap {{WRAPPER}} .wn-category-wrap, #wrap {{WRAPPER}} .wn-category-wrap .wn-category-posts',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-category-wrap',
				]
		);

		$this->add_control(
			'box_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'box_border',
				'label'    => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-category-wrap',
			]
		);

		$this->add_control(
			'box_border_radius',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .wn-category-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);		
		
		$this->add_responsive_control(
			'box_padding',
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .wn-category-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'box_margin',
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .wn-category-wrap' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
	
		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_box_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'box_bg_hover',
				'label'    => __( 'Background', 'deep' ),
				'types'    => [ 'classic' , 'gradient' ],
				'selector' => '#wrap {{WRAPPER}} .wn-category-wrap:hover, #wrap {{WRAPPER}} .wn-category-wrap:hover .wn-category-posts',
			]
		);			

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .wn-category-wrap:hover',
				]
		);

		$this->add_control(
			'box_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap:hover' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'box_border_hover',
				'label'    => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .wn-category-wrap:hover',
			]
		);

		$this->add_control(
			'box_border_radius_hover',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .wn-category-wrap:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'box_padding_hover',
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .wn-category-wrap:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->add_responsive_control(
			'box_margin_hover',
			[
				'label' 	  => __( 'Margin', 'deep' ),
				'type' 		  => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'  => [ 'px', 'em', '%' ],
				'selectors'   => [
					'#wrap {{WRAPPER}} .wn-category-wrap:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'box_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .wn-category-wrap' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->end_controls_section();

		// Custom css tab
		$this->start_controls_section(
			'custom_css_section',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'custom_css',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'type' => \Elementor\Controls_Manager::CODE,
				'language' => 'css',
				'rows' => 20,
				'show_label' => true,
			]
		);
		$this->end_controls_section();


	}

	/**
	 * Render Info Box widget output on the frontend.
	 *
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {

		$settings 	= $this->get_settings();


		if ( is_single() || is_page() ) {
			global $post;
			$post_slug = $post->post_name;
		}

		// Class & ID
		$shortcodeclass		= $settings['shortcodeclass'] ? $settings['shortcodeclass'] : '';
		$shortcodeid		= $settings['shortcodeid'] ? ' id="' . $settings['shortcodeid'] . '"' : '';
		$sort_order			= !empty( $settings['sort_order'] ) ? $settings['sort_order'] : '';
		$post_number		= '8';
		static $uniqid = 0;
		$uniqid++;

		$cat_ids = '';

		if ( !empty( $settings['param_category'] ) ) :
			$arrayKeys = array_keys($settings['param_category']);
			$lastArrayKey = array_pop($arrayKeys);

			foreach ( $settings['param_category'] as $key => $value ) {
				$get_cat 	= get_category_by_slug($value);
				if ( $get_cat ) {
					if($key == $lastArrayKey) {
						$get_cat_id = $get_cat->term_id;
					} else {
						$get_cat_id = $get_cat->term_id . ',';
					}
					$cat_ids .= $get_cat_id;
				}
			}
		endif;

		$args = array(
			'post_type' 		=> 'post',
			'posts_per_page'	=> -1,
			'cat'				=> $cat_ids,
			'orderby'			=> $sort_order
		);

		$out			= '';
		$category_tab 	= new \WP_Query( $args );
		$custom_css = $settings['custom_css'];

		if ( $custom_css != '' ) {
			echo '<style>'. $custom_css .'</style>';
		} ?>

		<div class="wn-category-wrap clearfix <?php echo '' . $shortcodeclass; ?>" <?php echo $shortcodeid; ?>>

			<?php if ( !empty( $settings['param_category'] ) ) {  ?>

					<ul class="wn-category-tab-nav">
						<?php $category_list = '
							<li class="active" data-cat-slug="all">
								<a href="' . get_permalink( get_option( 'page_for_posts' ) ) . '" class="all cat-item colorf" data-param_category="all">
									' . esc_html__( 'All', 'deep' ) . '
								</a>
							</li>'; ?>

						<?php
						foreach( $settings['param_category'] as $id => $cat_slug ) {
							$get_cats = get_category_by_slug($cat_slug);
							if ( $get_cats ) {
								$get_cats_id = $get_cats->term_id;
								if ( $cat_slug != null ) {
									$category_list .='
										<li data-cat-slug="' . $cat_slug . '">
											<a href="' . get_category_link( $get_cats_id ) . '" data-cat-slug="all ' . $cat_slug . '" class="cat-item">
												' . get_the_category_by_ID( $get_cats_id ) . '
											</a>
										</li>';
								}
							}

						}

						echo '' . $category_list; ?>
					</ul> <?php
				} ?>

				<div class="wn-category-posts clearfix" data-cat-slug="all"><?php

				if ( $category_tab->have_posts() ) {

					// The 2nd Loop
					while ( $category_tab->have_posts() ) {

						$category_tab->the_post();
						// $cat_id = the_category_ID( $echo = false );

						// thumbnail
						$thumbnail_url = get_the_post_thumbnail_url( $category_tab->post->ID );
						$thumbnail_id  = get_post_thumbnail_id( $category_tab->post->ID );
						if( !empty( $thumbnail_url ) ) {
							// if main class not exist get it
							if ( !class_exists( 'Wn_Img_Maniuplate' ) ) {
								require_once DEEP_CORE_DIR . 'helper-classes/class_webnus_manuplate.php';
							}
							$image = new \Wn_Img_Maniuplate; // instance from settor class
							$thumbnail_url = $image->m_image( $thumbnail_id, $thumbnail_url , '315' , '217' ); // set required and get result
						}

						?>
						<div class="wn-category-tab <?php echo '' . $uniqid; ?> wn-pagination active"  data-cat-slug="<?php echo get_the_terms( get_the_ID(), 'category' )[0]->slug; ?>">
							<article class="wn-category">
								<?php if( !empty($thumbnail_url) ): ?>
									<a href="<?php the_permalink() ?>">
										<img src="<?php echo '' . $thumbnail_url; ?> " alt="<?php the_title($category_tab->post->ID); ?>">
									</a>
								<?php  endif ?>
								<div class="wn-tab-cat-content">
									<?php if ( $settings['p_cat'] == 'show' ) { ?>
										<div class="wn-category-meta" style="background: <?php echo deep_category_color(); ?>;">
											<?php echo the_category(', '); ?>
										</div>
									<?php } ?>
									<?php if ( $settings['p_date'] == 'show' ) { ?>
										<div class="wn-category-date">
											<i class="pe-7s-clock"></i>
											<?php echo get_the_date(); ?>
										</div>
									<?php } ?>

									<h5 class="wn-category-title"><a class="hcolorf" href="<?php the_permalink($category_tab->post->ID); ?>"><?php the_title(); ?></a></h5>
								</div>
							</article>
						</div> <?php
					}


					// Restore original Post Data
					wp_reset_postdata();
				}?>
			</div>
		</div>

		<?php

	}

}
