<?php
namespace Elementor;

class Webnus_Element_Widgets_Magazine extends \Elementor\Widget_Base {

	/**
	 * Retrieve Magazine widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'magazine';
	}

	/**
	 * Retrieve Magazine widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Webnus Magazine', 'deep' );
	}

	/**
	 * Retrieve Magazine widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'icon-basic-postcard';
	}

	/**
	 * Set widget category.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget category.
	 */
	public function get_categories() {
		return [ 'webnus' ];
	}

	/**
	 * enqueue JS
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function get_script_depends() {
		return [ 'wn-magazine' ];
	}

	/**
	 * widget styles.
	 *
	 * @since 4.2.0
	 * @access public
	 *
	 */
	public function get_style_depends() {
		return [ 'wn-deep-magazine' ];
	}

	/**
	 * Register Magazine widget controls.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'General', 'deep' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$categories          = array();
		$categories          = get_categories();
		$category_slug_array = array( '' );
		$category_name_array = array( '' );
		foreach ( $categories as $category ) {
			$category_slug_array[] = $category->name;
			$category_name_array[] = $category->slug;
		}
		$category_array = array_combine( $category_name_array, $category_slug_array );

		$this->add_control(
			'type', 
			[
				'label'   => esc_html__( 'Type', 'deep' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => esc_html__( 'Type 1', 'deep' ),
					'2' => esc_html__( 'Type 2', 'deep' ),
					'3' => esc_html__( 'Type 3', 'deep' ),
				],
			]
		);
		$this->add_control(
			'post_title', 
			[
				'label'       => esc_html__( 'Title', 'deep' ), 
				'type'        => Controls_Manager::TEXT, 
				'placeholder' => esc_html__( 'Type your title text here', 'deep' ),
			]
		);
		$this->add_control(
			'post_url', 
			[
				'label'         => esc_html__( 'Title URL', 'deep' ), 
				'type'          => Controls_Manager::URL,
				'default'       => [
					'url'         => '',
					'is_external' => '',
				],
				'show_external' => false, // Show the 'open in new tab' button.
			]
		);
		$this->add_control(
			'param_category',
			[
				'label'    => esc_html__( 'Choose Categories', 'deep' ),
				'type'     => \Elementor\Controls_Manager::SELECT2,
				'multiple' => true,
				'options'  => $category_array,
			]
		);
		$this->add_control(
			'sort_order', 
			[
				'label'   => esc_html__( 'Sort Order', 'deep' ), 
				'type'    => Controls_Manager::SELECT, 
				'default' => 'date',
				'options' => [
					'date'          => esc_html__( 'Date', 'deep' ),
					'title'         => esc_html__( 'Title', 'deep' ),
					'comment_count' => esc_html__( 'Popular Post', 'deep' ),
					'latest'        => esc_html__( 'Recent Posts', 'deep' ),
					'rand'          => esc_html__( 'Random Posts', 'deep' ),
					'modified'      => esc_html__( 'Last Modified Post', 'deep' ),
				],
			]
		);
		$this->add_control(
			'post_number',
			[
				'label'   => esc_html__( 'Number Of Show Post', 'deep' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 8,
				'min'     => 1,
				'max'     => 24,
				'step'    => 1,
			]
		);
		$this->add_control(
			'post_prepage',
			[
				'label'   => esc_html__( 'Post Pre Page', 'deep' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 4,
				'min'     => 1,
				'max'     => 24,
				'step'    => 1,
			]
		);
		$this->add_control(
			'pagination',
			[
				'label'        => esc_html__( 'Pagination', 'deep' ),
				'type'         => Controls_Manager::SWITCHER,
				'default'      => '',
				'label_off'    => esc_html__( 'Hide', 'deep' ),
				'label_on'     => esc_html__( 'Show', 'deep' ),
				'return_value' => 'show',
				'default'      => 'show',
			]
		);
		$this->add_control(
			'reviews', 
			[
				'label'        => __( 'Reviews', 'deep' ), 
				'type'         => \Elementor\Controls_Manager::SWITCHER, 
				'label_on'     => __( 'Show', 'deep' ),
				'label_off'    => __( 'Hide', 'deep' ),
				'return_value' => 'show',
				'default'      => 'show',
			]
		);
		$this->add_control(
			'hide_cat', 
			[
				'label'        => __( 'Post Category', 'deep' ), 
				'type'         => \Elementor\Controls_Manager::SWITCHER, 
				'label_on'     => __( 'Show', 'deep' ),
				'label_off'    => __( 'Hide', 'deep' ),
				'return_value' => 'show',
				'default'      => 'show',
			]
		);
		$this->add_control(
			'hide_date', 
			[
				'label'        => __( 'Post Date', 'deep' ), 
				'type'         => \Elementor\Controls_Manager::SWITCHER, 
				'label_on'     => __( 'Show', 'deep' ),
				'label_off'    => __( 'Hide', 'deep' ),
				'return_value' => 'show',
				'default'      => 'show',
			]
		);
		$this->add_control(
			'hide_author', 
			[
				'label'        => __( 'Post Author', 'deep' ), 
				'type'         => \Elementor\Controls_Manager::SWITCHER, 
				'label_on'     => __( 'Show', 'deep' ),
				'label_off'    => __( 'Hide', 'deep' ),
				'return_value' => 'show',
				'default'      => 'show',
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'classid_section',
			[
				'label' => __( 'Class & ID', 'deep' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'shortcodeclass',
			[
				'label' => esc_html__( 'Extra Class', 'deep' ),
				'type'  => Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'shortcodeid',
			[
				'label' => esc_html__( 'ID', 'deep' ),
				'type'  => Controls_Manager::TEXT,
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'images_style',
			[
				'label' => __( 'Images Style', 'deep' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'images_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-img img, #wrap {{WRAPPER}} .magazine-b2-img img, #wrap {{WRAPPER}} .magazine-b3-img img' => 'display: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'image_style_tabs'
		);

		$this->start_controls_tab(
			'style_image_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Css_Filter::get_type(),
			[
				'name'     => 'image_filters',
				'label' => __( 'Image Filter', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-b1-img img, #wrap {{WRAPPER}} .magazine-b2-img img, #wrap {{WRAPPER}} .magazine-b3-img img',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'images_bg',
				'label'    => __( 'Background', 'deep' ),
				'types'    => [ 'classic' , 'gradient' ],
				'selector' => '#wrap {{WRAPPER}} .magazine-b1-img img, #wrap {{WRAPPER}} .magazine-b2-img img, #wrap {{WRAPPER}} .magazine-b3-img img',
			]
		);		

		$this->add_control(
			'images_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-img img, #wrap {{WRAPPER}} .magazine-b2-img img, #wrap {{WRAPPER}} .magazine-b3-img img' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'images_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .magazine-b1-img img, #wrap {{WRAPPER}} .magazine-b2-img img, #wrap {{WRAPPER}} .magazine-b3-img img',
				]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'images_border',
				'label'    => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-b1-img img, #wrap {{WRAPPER}} .magazine-b2-img img, #wrap {{WRAPPER}} .magazine-b3-img img',
			]
		);

		$this->add_control(
			'images_border_radius',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazine-b1-img img, #wrap {{WRAPPER}} .magazine-b2-img img, #wrap {{WRAPPER}} .magazine-b3-img img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'images_padding',
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazine-b1-img img, #wrap {{WRAPPER}} .magazine-b2-img img, #wrap {{WRAPPER}} .magazine-b3-img img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'images_margin',
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazine-b1-img img, #wrap {{WRAPPER}} .magazine-b2-img img, #wrap {{WRAPPER}} .magazine-b3-img img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_image_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Css_Filter::get_type(),
			[
				'name'     => 'image_filters_hover',
				'label' => __( 'Image Filter', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-b1-img img:hover, #wrap {{WRAPPER}} .magazine-b2-img img:hover, #wrap {{WRAPPER}} .magazine-b3-img img:hover',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'images_bg_hover',
				'label'    => __( 'Background', 'deep' ),
				'types'    => [ 'classic' , 'gradient' ],
				'selector' => '#wrap {{WRAPPER}} .magazine-b1-img img:hover, #wrap {{WRAPPER}} .magazine-b2-img img:hover, #wrap {{WRAPPER}} .magazine-b3-img img:hover',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'images_border_hover',
				'label'    => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-b1-img img:hover, #wrap {{WRAPPER}} .magazine-b2-img img:hover, #wrap {{WRAPPER}} .magazine-b3-img img:hover',
			]
		);

		$this->add_control(
			'images_border_radius_hover',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazine-b1-img img:hover, #wrap {{WRAPPER}} .magazine-b2-img img:hover, #wrap {{WRAPPER}} .magazine-b3-img img:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);			
				
		$this->add_control(
			'images_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-img img:hover, #wrap {{WRAPPER}} .magazine-b2-img img:hover, #wrap {{WRAPPER}} .magazine-b3-img img:hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'images_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .magazine-b1-img img:hover, #wrap {{WRAPPER}} .magazine-b2-img img:hover, #wrap {{WRAPPER}} .magazine-b3-img img:hover',
				]
		);

		$this->add_control(
			'images_padding_hover',
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazine-b1-img img:hover, #wrap {{WRAPPER}} .magazine-b2-img img:hover, #wrap {{WRAPPER}} .magazine-b3-img img:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'images_margin_hover',
			[
				'label' 	  => __( 'Margin', 'deep' ),
				'type' 		  => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'  => [ 'px', 'em', '%' ],
				'selectors'   => [
					'#wrap {{WRAPPER}} .magazine-b1-img img:hover, #wrap {{WRAPPER}} .magazine-b2-img img:hover, #wrap {{WRAPPER}} .magazine-b3-img img:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'image_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-img img, #wrap {{WRAPPER}} .magazine-b2-img img, #wrap {{WRAPPER}} .magazine-b3-img img' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_title_style',
			[
				'label' => __( 'Title', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_text_align',
			[
				'label'     => __( 'Text align', 'deep' ),
				'type'      => \Elementor\Controls_Manager::CHOOSE,
				'options'   => [
					'left'   => [
						'title' => __( 'Left', 'deep' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'deep' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'  => [
						'title' => __( 'Right', 'deep' ),
						'icon'  => 'fa fa-align-right',
					],
				],				
				'toggle'    => true,
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title , #wrap {{WRAPPER}} .magazine-b2-title , #wrap {{WRAPPER}} .magazine-b3-title ' => 'text-align: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'title_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title, #wrap {{WRAPPER}} .magazine-b2-title , #wrap {{WRAPPER}} .magazine-b3-title ' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_control(
			'title_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title , #wrap {{WRAPPER}} .magazine-b2-title , #wrap {{WRAPPER}} .magazine-b3-title ' => 'display: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'title_style_tabs'
		);

		$this->start_controls_tab(
			'style_title_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'title_typography',
				'label' 	=> __( 'Title Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .magazine-b1-title a, #wrap {{WRAPPER}} .magazine-b2-title a, #wrap {{WRAPPER}} .magazine-b3-title a',
			]
		);

		$this->add_control(
			'post_title_color',
			[
				'label'     => esc_html__( 'Title Color', 'deep' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
				'default'   => '#437df9',
				'selectors' => [
					'{{WRAPPER}} .magazin-title,#wrap {{WRAPPER}} .magazine-b1-title a, #wrap {{WRAPPER}} .magazine-b2-title a, #wrap {{WRAPPER}} .magazine-b3-title a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' ],
				'selector' => '#wrap {{WRAPPER}} .magazine-b1-title a, #wrap {{WRAPPER}} .magazine-b2-title a, #wrap {{WRAPPER}} .magazine-b3-title a',
			]
		);

		$this->add_control(
			'title_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title a, #wrap {{WRAPPER}} .magazine-b2-title a, #wrap {{WRAPPER}} .magazine-b3-title a' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'title_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .magazine-b1-title a, #wrap {{WRAPPER}} .magazine-b2-title a, #wrap {{WRAPPER}} .magazine-b3-title a',
				]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'title_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-b1-title a, #wrap {{WRAPPER}} .magazine-b2-title a, #wrap {{WRAPPER}} .magazine-b3-title a',
			]
		);

		$this->add_control(
			'title_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title a, #wrap {{WRAPPER}} .magazine-b2-title a, #wrap {{WRAPPER}} .magazine-b3-title a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'title_padding', 
			[
				'label' 		=> __( 'Title padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title a, #wrap {{WRAPPER}} .magazine-b2-title a, #wrap {{WRAPPER}} .magazine-b3-title a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'title_margin', 
			[
				'label' 		=> __( 'Title margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title a, #wrap {{WRAPPER}} .magazine-b2-title a, #wrap {{WRAPPER}} .magazine-b3-title a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_title_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'title_typography_hover',
				'label' 	=> __( 'Title Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .magazine-b1-title a:hover, #wrap {{WRAPPER}} .magazine-b2-title a:hover, #wrap {{WRAPPER}} .magazine-b3-title a:hover',
			]
		);

		$this->add_control(
			'title_color_hover', 
			[
				'label' 		=> __( 'Title color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .magazine-b1-title a:hover, #wrap {{WRAPPER}} .magazine-b2-title a:hover, #wrap {{WRAPPER}} .magazine-b3-title a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'title_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' ],
				'selector' => '#wrap {{WRAPPER}} .magazine-b1-title a:hover, #wrap {{WRAPPER}} .magazine-b2-title a:hover, #wrap {{WRAPPER}} .magazine-b3-title a:hover',
			]
		);	

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'title_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-b1-title a:hover, #wrap {{WRAPPER}} .magazine-b2-title a:hover, #wrap {{WRAPPER}} .magazine-b3-title a:hover',
			]
		);	
		
		$this->add_control(
			'title_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title a:hover, #wrap {{WRAPPER}} .magazine-b2-title a:hover, #wrap {{WRAPPER}} .magazine-b3-title a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'title_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title a:hover, #wrap {{WRAPPER}} .magazine-b2-title a:hover, #wrap {{WRAPPER}} .magazine-b3-title a:hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'title_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .magazine-b1-title a:hover, #wrap {{WRAPPER}} .magazine-b2-title a:hover, #wrap {{WRAPPER}} .magazine-b3-title a:hover',
				]
		);

		$this->add_control(
			'title_padding_hover', 
			[
				'label' 		=> __( 'Title padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title a:hover, #wrap {{WRAPPER}} .magazine-b2-title a:hover, #wrap {{WRAPPER}} .magazine-b3-title a:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'title_margin_hover', 
			[
				'label' 		=> __( 'Title margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title a:hover, #wrap {{WRAPPER}} .magazine-b2-title a:hover, #wrap {{WRAPPER}} .magazine-b3-title a:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);	

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'title_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title a, #wrap {{WRAPPER}} .magazine-b2-title a, #wrap {{WRAPPER}} .magazine-b3-title a' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'title_position',
			[
				'label' => __( 'Position', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					''  => __( 'Default', 'deep' ),
					'relative'  => __( 'Relative', 'deep' ),
					'absolute' => __( 'Absolute', 'deep' ),
					'fixed' => __( 'Fixed', 'deep' ),
					'static' => __( 'Static', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title, #wrap {{WRAPPER}} .magazine-b2-title, #wrap {{WRAPPER}} .magazine-b3-title' => 'position: {{VALUE}}',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'title_pos_top',
			[
				'label' => __( 'Top', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title, #wrap {{WRAPPER}} .magazine-b2-title, #wrap {{WRAPPER}} .magazine-b3-title' => 'top: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'title_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'title_pos_right',
			[
				'label' => __( 'Right', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title, #wrap {{WRAPPER}} .magazine-b2-title, #wrap {{WRAPPER}} .magazine-b3-title' => 'right: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'title_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'title_pos_bottom',
			[
				'label' => __( 'Bottom', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title, #wrap {{WRAPPER}} .magazine-b2-title, #wrap {{WRAPPER}} .magazine-b3-title' => 'bottom: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'title_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'title_pos_left',
			[
				'label' => __( 'Left', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-b1-title, #wrap {{WRAPPER}} .magazine-b2-title, #wrap {{WRAPPER}} .magazine-b3-title' => 'left: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'title_position'      => array( 'relative','absolute','fixed' ),
				),
			]
    );
		
		$this->end_controls_section();

		// Author Style
		$this->start_controls_section(
			'section_author_style',
			[
				'label' => __( 'Author', 'deep' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'author_text_align',
			[
				'label'     => __( 'Text align', 'deep' ),
				'type'      => \Elementor\Controls_Manager::CHOOSE,
				'options'   => [
					'left'   => [
						'title' => __( 'Left', 'deep' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'deep' ),
						'icon'  => 'fa fa-align-center',
					],
					'right'  => [
						'title' => __( 'Right', 'deep' ),
						'icon'  => 'fa fa-align-right',
					],
				],				
				'toggle'    => true,
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author' => 'text-align: {{VALUE}}',
				],
			]
		);

		$this->add_responsive_control(
			'author_float',
			[
				'label'     => __( 'Float', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'right'      => __( 'Right', 'deep' ),
					'left'       => __( 'Left', 'deep' ),
					'unset' => __( 'Unset', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author' => 'float: {{VALUE}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_control(
			'author_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author' => 'display: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'author_style_tabs'
		);

		$this->start_controls_tab(
			'style_author_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'author_typography',
				'label' 	=> __( 'Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .magazine-author span a',
			]
		);

		$this->add_control(
			'post_author_color',
			[
				'label'     => esc_html__( 'Color', 'deep' ),
				'type'      => Controls_Manager::COLOR,
				'scheme'    => [
					'type'  => \Elementor\Core\Schemes\Color::get_type(),
					'value' => \Elementor\Core\Schemes\Color::COLOR_1,
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'author_bg',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' ],
				'selector' => '#wrap {{WRAPPER}} .magazine-author span a',
			]
		);

		$this->add_control(
			'author_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'author_box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .magazine-author span a',
				]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'author_border',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-author span a',
			]
		);

		$this->add_control(
			'author_border_radius', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'author_padding', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'author_margin', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);	

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_author_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'author_typography_hover',
				'label' 	=> __( ' Typography', 'deep' ),
				'scheme'    => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_2,
				'selector' 	=> '#wrap {{WRAPPER}} .magazine-author span a:hover',
			]
		);

		$this->add_control(
			'author_color_hover', 
			[
				'label' 		=> __( 'Color', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::COLOR,
				'selectors' 	=> [
					'#wrap {{WRAPPER}} .magazine-author span a:hover' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'author_bg_hover',
				'label' => __( 'Background', 'deep' ),
				'types' => [ 'classic' ],
				'selector' => '#wrap {{WRAPPER}} .magazine-author span a:hover',
			]
		);	

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'author_border_hover',
				'label' => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-author span a:hover',
			]
		);	
		
		$this->add_control(
			'author_border_radius_hover', 
			[
				'label' 		=> __( 'Border Radius', 'deep' ), 
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS, 
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
		$this->add_control(
			'author_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a:hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'author_box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .magazine-author span a:hover',
				]
		);

		$this->add_control(
			'author_padding_hover', 
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'author_margin_hover', 
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);	

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'author_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'author_position',
			[
				'label' => __( 'Position', 'deep' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					''  => __( 'Default', 'deep' ),
					'relative'  => __( 'Relative', 'deep' ),
					'absolute' => __( 'Absolute', 'deep' ),
					'fixed' => __( 'Fixed', 'deep' ),
					'static' => __( 'Static', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a' => 'position: {{VALUE}}',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		
		$this->add_responsive_control(
			'author_pos_top',
			[
				'label' => __( 'Top', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a' => 'top: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'author_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'author_pos_right',
			[
				'label' => __( 'Right', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a' => 'right: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'author_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'author_pos_bottom',
			[
				'label' => __( 'Bottom', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a' => 'bottom: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'author_position'      => array( 'relative','absolute','fixed' ),
				),
			]
		);

		$this->add_responsive_control(
			'author_pos_left',
			[
				'label' => __( 'Left', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
						'step' => 5,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => '',
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span a' => 'left: {{SIZE}}{{UNIT}};',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'condition'     => array(
					'author_position'      => array( 'relative','absolute','fixed' ),
				),
			]
    );
		
		$this->add_control(
			'author_img_heading',
			[
				'label' => __( 'Author Image', 'deep' ),
				'type' => \Elementor\Controls_Manager::HEADING,
				'separator' => 'before',
			]
		);

		$this->add_control(
			'author_image_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span img' => 'display: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'author_img_style_tabs'
		);

		$this->start_controls_tab(
			'style_author_img_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Css_Filter::get_type(),
			[
				'name'     => 'author_img_filters',
				'label' => __( 'Image Filter', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-author span img',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'author_images_bg',
				'label'    => __( 'Background', 'deep' ),
				'types'    => [ 'classic' , 'gradient' ],
				'selector' => '#wrap {{WRAPPER}} .magazine-author span img',
			]
		);		

		$this->add_control(
			'author_img_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span img' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'author_img_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .magazine-author span img',
				]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'author_img_border',
				'label'    => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-author span img',
			]
		);

		$this->add_control(
			'author_img_border_radius',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazine-author span img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'author_img_padding',
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazine-author span img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'author_img_margin',
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazine-author span img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_author_img_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Css_Filter::get_type(),
			[
				'name'     => 'author_img_filters_hover',
				'label' => __( 'Image Filter', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-author:hover span img',
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'author_images_bg_hover',
				'label'    => __( 'Background', 'deep' ),
				'types'    => [ 'classic' , 'gradient' ],
				'selector' => '#wrap {{WRAPPER}} .magazine-author:hover span img',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'author_img_border_hover',
				'label'    => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazine-author:hover span img',
			]
		);

		$this->add_control(
			'author_img_border_radius_hover',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazine-author:hover span img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);			
				
		$this->add_control(
			'author_img_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author:hover span img' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'author_img_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .magazine-author:hover span img',
				]
		);

		$this->add_control(
			'author_img_padding_hover',
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazine-author:hover span img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'author_img_margin_hover',
			[
				'label' 	  => __( 'Margin', 'deep' ),
				'type' 		  => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'  => [ 'px', 'em', '%' ],
				'selectors'   => [
					'#wrap {{WRAPPER}} .magazine-author:hover span img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'author_img_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .magazine-author span img' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->end_controls_section();

		// Box Style
		$this->start_controls_section(
			'box_style',
			[
				'label' => __( 'Box Style', 'deep' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'box_display',
			[
				'label'     => __( 'Display', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'      => __( 'Inherit', 'deep' ),
					'inline'       => __( 'inline', 'deep' ),
					'inline-block' => __( 'inline block', 'deep' ),
					'block'        => __( 'block', 'deep' ),
					'none'         => __( 'none', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazin-wrap' => 'display: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'box_overflow ',
			[
				'label'     => __( 'Overflow', 'deep' ), 
				'type'      => \Elementor\Controls_Manager::SELECT,		
				'options'   => [ 
					''      => __( 'Default', 'deep' ),
					'inherit'   => __( 'inherit', 'deep' ),
					'scroll'    => __( 'scroll', 'deep' ),
					'hidden'    => __( 'hidden', 'deep' ),
					'auto' 		=> __( 'auto', 'deep' ),
					'visible'   => __( 'visible', 'deep' ),
				],
				'selectors' => [
					'#wrap {{WRAPPER}} .magazin-wrap' => 'overflow: {{VALUE}};',
				],
			]
		);

		$this->start_controls_tabs(
			'box_style_tabs'
		);

		$this->start_controls_tab(
			'style_box_normal_tab',
			[
				'label' => __( 'Normal', 'deep' ),
			]
		);
		
		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'box_bg',
				'label'    => __( 'Background', 'deep' ),
				'types'    => [ 'classic' , 'gradient' ],
				'selector' => '#wrap {{WRAPPER}} .magazin-wrap',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'box_shadow',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .magazin-wrap',
				]
		);

		$this->add_control(
			'box_opacity',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .magazin-wrap' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'box_border',
				'label'    => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazin-wrap',
			]
		);

		$this->add_control(
			'box_border_radius',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazin-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);		
		
		$this->add_control(
			'box_padding',
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazin-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'box_margin',
			[
				'label' 		=> __( 'Margin', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazin-wrap' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
	
		$this->end_controls_tab();

		$this->start_controls_tab(
			'style_box_hover_tab',
			[
				'label' => __( 'Hover', 'deep' ),
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name'     => 'box_bg_hover',
				'label'    => __( 'Background', 'deep' ),
				'types'    => [ 'classic' , 'gradient' ],
				'selector' => '#wrap {{WRAPPER}} .magazin-wrap:hover',
			]
		);			

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
				[
					'name'     => 'box_shadow_hover',
					'label'    => __( 'Box Shadow', 'deep' ),
					'selector' => '#wrap {{WRAPPER}} .magazin-wrap:hover',
				]
		);

		$this->add_control(
			'box_opacity_hover',
			[
				'label' => __( 'Opacity', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1,
						'step' => 0.1,
					],
				],			
				'selectors' => [
					'#wrap {{WRAPPER}} .magazin-wrap:hover' => 'opacity: {{SIZE}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name'     => 'box_border_hover',
				'label'    => __( 'Border', 'deep' ),
				'selector' => '#wrap {{WRAPPER}} .magazin-wrap:hover',
			]
		);

		$this->add_control(
			'box_border_radius_hover',
			[
				'label' 		=> __( 'Border Radius', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazin-wrap:hover' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'box_padding_hover',
			[
				'label' 		=> __( 'Padding', 'deep' ),
				'type' 			=> \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', 'em', '%' ],
				'selectors'     => [
					'#wrap {{WRAPPER}} .magazin-wrap:hover' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'box_margin_hover',
			[
				'label' 	  => __( 'Margin', 'deep' ),
				'type' 		  => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units'  => [ 'px', 'em', '%' ],
				'selectors'   => [
					'#wrap {{WRAPPER}} .magazin-wrap:hover' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'box_transition',
			[
				'label' => __( 'Transition', 'deep' ),
				'type' => Controls_Manager::SLIDER,
				'selectors' => [
					'#wrap {{WRAPPER}} .magazin-wrap' => 'transition: all {{SIZE}}s ease;',
				],
				'separator' => 'before',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'custom_css_section',
			[
				'label' => __( 'Custom CSS', 'deep' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'custom_css',
			[
				'label'      => __( 'Custom CSS', 'deep' ),
				'type'       => \Elementor\Controls_Manager::CODE,
				'language'   => 'css',
				'rows'       => 20,
				'show_label' => true,
			]
		);
		$this->end_controls_section();

	}

	/**
	 * Render Magazine widget output on the frontend.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings();

		global $post;
		$post_slug = $post->post_name;

		// Class & ID
		$shortcodeclass = $settings['shortcodeclass'] ? $settings['shortcodeclass'] : '';
		$shortcodeid    = $settings['shortcodeid'] ? ' id=' . $settings['shortcodeid'] . '' : '';
		$sort_order      = ! empty( $settings['sort_order'] ) ? $settings['sort_order'] : '';
		$post_number     = ! empty( $settings['post_number'] ) ? $settings['post_number'] : '';
		$post_title      = ! empty( $settings['post_title'] ) ? $settings['post_title'] : '';
		$post_prepage    = ! empty( $settings['post_prepage'] ) ? $settings['post_prepage'] : '';
		$post_url        = ! empty( $settings['post_url']['url'] ) ? $settings['post_url']['url'] : '';
		$pagination      = $settings['pagination'] == 'show' ? ' show-pagination ' : ' hide-pagination ';
		$type            = ! empty( $settings['type'] ) ? $settings['type'] : '';
		$hide_cat        = $settings['hide_cat'] == '' ? ' hide-cat ' : '';
		$hide_date       = $settings['hide_date'] == '' ? ' hide-date ' : '';
		$hide_author     = $settings['hide_author'] == '' ? ' hide-author ' : '';
		$shortcodeclass .= $hide_cat . $hide_date . $hide_author . $pagination;
		$cat_ids = $param_tag = $excerpt_value = $thumbnail_url_1 = $thumbnail_url_2 = '';

		if ( ! empty( $settings['param_category'] ) ) :
			$arrayKeys    = array_keys( $settings['param_category'] );
			$lastArrayKey = array_pop( $arrayKeys );

			foreach ( $settings['param_category'] as $key => $value ) {
				$get_cat = get_category_by_slug( $value );

				if ( $get_cat ) {
					if ( $key == $lastArrayKey ) {
						$get_cat_id = $get_cat->term_id;
					} else {
						$get_cat_id = $get_cat->term_id . ',';
					}
					$cat_ids .= $get_cat_id;
				}
				
			}
		endif;

		$args = array(
			'post_type'      => 'post',
			'posts_per_page' => $post_number,
			'cat'            => $cat_ids,
			'orderby'        => $sort_order,
		);

		$custom_query = new \WP_Query( $args );
		$temp_query   = $custom_query;
		$custom_query = null;
		$magazine     = $temp_query;

		$totall_post = $magazine->post_count ? $magazine->post_count : '';

		$custom_css = $settings['custom_css'];

		if ( $custom_css != '' ) {
			echo '<style>' . $custom_css . '</style>';
		}

		if ( $type == '1' ) {
			static $magazin_uniqid = 0;
			$magazin_uniqid++;
			?>

		<div 
		class="magazin-wrap magazin-<?php echo '' . $type . ' ' . $shortcodeclass; ?>"
		 <?php echo esc_attr( $shortcodeid ); ?>
		data-id="<?php echo esc_attr( $magazin_uniqid ); ?>"
		data-post-name="<?php echo esc_attr( $post_slug ); ?>"
		data-totall_post="<?php echo esc_attr( $totall_post ); ?>"
		data-pagination="<?php echo esc_attr( $pagination ); ?>"
		data-param_category="<?php echo esc_attr( $cat_ids ); ?>"
		data-param_tag="<?php echo esc_attr( $param_tag ); ?>"
		data-post_title="<?php echo esc_html( $post_title ); ?>"
		data-post_url="<?php echo esc_attr( $post_url ); ?>"
		data-type="<?php echo esc_attr( $type ); ?>"
		data-sort_order="<?php echo esc_attr( $sort_order ); ?>"
		data-post_number="<?php echo esc_attr( $post_number ); ?>"
		data-post_prepage="<?php echo esc_attr( $post_prepage ); ?>"
		>

			<?php static $title_uniqid = 0; $title_uniqid++; ?>
			<?php if ($post_url): ?>
					<?php $post_title = $post_title ? '<a href="' . $post_url . '"><h4 class="magazin-title" data-id="' . $title_uniqid . '">' . $post_title . '</h4></a>' : '';  ?>				
			<?php else: ?>
					<?php $post_title = $post_title ? '<h4 class="magazin-title" data-id="' . $title_uniqid . '">' . $post_title . '</h4>' : '';  ?>				
			<?php endif; ?>
			<div class="clearfix">
				
			<?php if ( ! empty( $settings['param_category'] ) ) { ?>
			
				<div class="magazin-cat-nav-wrap">
					<?php echo wp_kses( $post_title, wp_kses_allowed_html( 'post' ) ); ?>
					<ul class="magazin-cat-nav">
						<?php $category_list = '<li><a href="#" class="all cat-item colorf" data-param_category="' . $cat_ids . '">' . esc_html__( 'All', 'deep' ) . '</a></li>'; ?>
						<?php $cat_counter = 0; ?>
						<?php $catsize = sizeof( $settings['param_category'] ); ?>
						<?php
						foreach ( $settings['param_category'] as $id => $cat_slug ) {
							$get_cats = get_category_by_slug( $cat_slug );
						
							if ( $get_cats ) {
								$cat_id   = $get_cats->term_id;

								$cat_counter++;
								$total_cat_counter = $cat_counter;

								$start_ul      = ( $cat_counter == 5 ) ? '<li class="magazin-dropdown-list"><i class="sl-options"></i><ul>' : '';
								$category_term = get_term( $cat_id, 'category' );
								if ( $category_term ) {
									$category_list .= $start_ul . '<li><a href="#" data-cat-slug="' . $category_term->slug . '" class="cat-item" data-param_category="' . $cat_id . '">' . $category_term->name . '</a></li>';
								}
							}							
						}
						if ( $cat_counter == 5 ) {
							if ( $cat_counter == $catsize ) {
								$end_ul         = '</ul></li>';
								$category_list .= $end_ul;
							}
						}
						echo '' . $category_list;
						?>
					</ul>
				</div>
			
			<?php } ?>

			<div class="magazin-wrap-content">
				
				<?php
				$post_counter = 0;
				if ( $magazine->have_posts() ) {
					?>
					<?php
					static $uniqid = 0;
					while ( $magazine->have_posts() ) {
						$post_counter++;
						$magazine->the_post();

						$uniqid++;
						$thumbnail_url = get_the_post_thumbnail_url();
						$thumbnail_id  = get_post_thumbnail_id();

						if ( ! empty( $thumbnail_url ) ) {
							if ( ! class_exists( 'Wn_Img_Maniuplate' ) ) {
								require_once DEEP_CORE_DIR . 'helper-classes/class_webnus_manuplate.php';

							}
							$image         = new \Wn_Img_Maniuplate(); // instance from settor class
							$thumbnail_url = $image->m_image( $thumbnail_id, $thumbnail_url, '508', '300' ); // set required and get result
						}
						?>

						<?php if ( $post_counter % 2 == 1 ) { ?>
							<div class="row">
						<?php } ?>
								<div class="col-md-6 wn-pagination" >
									<article class="magazine-b<?php echo '' . $type; ?> magazine-b<?php echo '' . $type; ?>-cont" data-id="<?php echo '' . $uniqid; ?>">
										<figure class="magazine-b<?php echo '' . $type; ?>-img">
											<a href="<?php the_permalink(); ?>">
												<?php if ( ! empty( $thumbnail_url ) ) : ?>												
													<img src="<?php echo '' . $thumbnail_url; ?>" alt="<?php the_title(); ?>" >
												<?php else : ?>
													<img src="<?php echo DEEP_ASSETS_URL . 'images/featured.jpg'; ?>"  alt="<?php echo get_the_title(); ?>"/>					
												<?php endif ?>												
											</a>
										</figure>
										<div class="magazine-b<?php echo '' . $type; ?>-cont">
											<?php
											if ( $hide_cat != 'true' ) {
												?>
												<div class="magazine-b<?php echo '' . $type; ?>-category" style="background: <?php echo deep_category_color(); ?>;">
														<span class="magazine-b<?php echo '' . $type; ?>-cat magazine-cat" data-id="<?php echo '' . $uniqid; ?>"><?php the_category( ', ' ); ?></span>
												</div>
												<?php
											}
											?>
											<div class="magazine-b<?php echo '' . $type; ?>-date">
												<i class="pe-7s-clock"></i><?php echo get_the_date(); ?>
											</div>
											<h3 class="magazine-b<?php echo '' . $type; ?>-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
											<div class="magazine-author">
												<span><?php echo get_avatar( get_the_author_meta( 'user_email' ), 28 ); ?></span>
												<span><?php the_author_posts_link(); ?></span>	
											</div>
											<?php $reviews = $settings['reviews'] == 'show' ? deep_admin_post_review() : ''; ?>
										</div>
									</article>
								</div>
						<?php if ( $post_counter % 2 == 0 ) { ?>
							</div>
						<?php } ?>
					<?php } ?>
			</div>
		</div><!-- End magazin-wrap  -->
			<?php } ?>
		</div>
			<?php
		} elseif ( $type == '2' ) {
			static $magazin_uniqid = 0;
			$magazin_uniqid++;
			?>

		<div 
			class="magazin-wrap magazin-<?php echo esc_attr( $type ) . ' ' . $shortcodeclass; ?>"
			<?php echo esc_attr( $shortcodeid ); ?>
			data-id="<?php echo esc_attr( $magazin_uniqid ); ?>"
			data-post-name="<?php echo esc_attr( $post_slug ); ?>"
			data-totall_post="<?php echo esc_attr( $totall_post ); ?>"
			data-pagination="<?php echo esc_attr( $pagination ); ?>"
			data-param_category="<?php echo esc_attr( $cat_ids ); ?>"
			data-param_tag="<?php echo esc_attr( $param_tag ); ?>"
			data-post_title="<?php echo esc_attr( $post_title ); ?>"
			data-post_url="<?php echo esc_attr( $post_url ); ?>"
			data-type="<?php echo esc_attr( $type ); ?>"
			data-sort_order="<?php echo esc_attr( $sort_order ); ?>"
			data-post_number="<?php echo esc_attr( $post_number ); ?>"
			data-post_prepage="<?php echo esc_attr( $post_prepage ); ?>"
			data-excerpt_value="<?php echo esc_attr( $excerpt_value ); ?>"
		>
			<?php
			static $title_uniqid = 0;
			$title_uniqid++;

			$post_title = $post_title ? '<h4 class="magazin-title" data-id="' . $title_uniqid . '">' . $post_title . '</h4>' : '';
			?>
			<div class="clearfix">
					
				<?php if ( ! empty( $settings['param_category'] ) ) { ?>
				
					<div class="magazin-cat-nav-wrap">
						<?php echo wp_kses( $post_title, wp_kses_allowed_html( 'post' ) ); ?>
						<ul class="magazin-cat-nav">
							<?php $category_list = '<li><a href="#" class="all cat-item colorf" data-param_category="' . $cat_ids . '">' . esc_html__( 'All', 'deep' ) . '</a></li>'; ?>
							<?php $cat_counter = 0; ?>
							<?php $catsize = sizeof( $settings['param_category'] ); ?>
							<?php
							foreach ( $settings['param_category'] as $id => $cat_slug ) {
								$get_cats = get_category_by_slug( $cat_slug );
								

								if ( $get_cats ) {
									$cat_id   = $get_cats->term_id;
									$cat_counter++;
									$total_cat_counter = $cat_counter;

									$start_ul = ( $cat_counter == 5 ) ? '<li class="magazin-dropdown-list"><i class="sl-options"></i><ul>' : '';

									$category_list .= $start_ul . '<li><a href="#" data-cat-slug="' . deep_get_cat_slug( $cat_id ) . '" class="cat-item" data-param_category="' . $cat_id . '">' . get_the_category_by_ID( $cat_id ) . '</a></li>';
								}
								
							}
							if ( $cat_counter == 5 ) {
								if ( $cat_counter == $catsize ) {
									$end_ul         = '</ul></li>';
									$category_list .= $end_ul;
								}
							}
							echo '' . $category_list;
							?>
						</ul>
					</div>
				
				<?php } ?>

				<div class="magazin-wrap-content">
					
					<?php
					$first_post   = true;
					$post_counter = 0;
						// The Loop
					if ( $magazine->have_posts() ) {
						static $uniqid = 0;
						?>

						<div class="row">
							<?php
							while ( $magazine->have_posts() ) {
								$post_counter++;
								$magazine->the_post();
								$uniqid++;
								$thumbnail_url = get_the_post_thumbnail_url();
								$thumbnail_id  = get_post_thumbnail_id();
								if ( ! empty( $thumbnail_url ) ) {
									if ( ! class_exists( 'Wn_Img_Maniuplate' ) ) {
										require_once DEEP_CORE_DIR . 'helper-classes/class_webnus_manuplate.php';
									}
									$image           = new \Wn_Img_Maniuplate(); // instance from settor class
									$thumbnail_url_1 = $image->m_image( $thumbnail_id, $thumbnail_url, '508', '300' ); // set required and get result
									$thumbnail_url_2 = $image->m_image( $thumbnail_id, $thumbnail_url, '120', '80' ); // set required and get result
								}
								if ( $first_post == true ) {
									?>
									<div class="col-md-6">
										<div class="left-section">
											<article class="magazine-b<?php echo '' . $type; ?> magazine-b<?php echo '' . $type; ?>-cont" data-id="<?php echo '' . $uniqid; ?>">
												<figure class="magazine-b<?php echo '' . $type; ?>-img">
													<img src="<?php echo '' . $thumbnail_url_1; ?>" alt="<?php the_title(); ?>" >
												</figure>
												<div class="magazine-b<?php echo '' . $type; ?>-cont">
													<?php
													if ( $hide_cat != 'true' ) {
														?>
														<div class="magazine-b<?php echo '' . $type; ?>-category" style="background: <?php echo deep_category_color(); ?>;">
															<span class="magazine-b<?php echo '' . $type; ?>-cat magazine-cat" data-id="<?php echo '' . $uniqid; ?>"><?php the_category( ', ' ); ?></span>
														</div>												
														<?php
													}
													?>
													<div class="magazine-b<?php echo '' . $type; ?>-date">
														<i class="pe-7s-clock"></i><?php echo get_the_date(); ?>
													</div>
													<h3 class="magazine-b<?php echo '' . $type; ?>-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
													<div class="magazine-author">
														<span><?php echo get_avatar( get_the_author_meta( 'user_email' ), 28 ); ?></span>
														<span><?php the_author_posts_link(); ?></span>	
													</div>
													<?php $reviews = $settings['reviews'] == 'show' ? deep_admin_post_review() : ''; ?>
												</div>
											</article>
										</div>
									</div>
								<?php } else { ?>
										<?php if ( $post_counter == 2 ) { ?>
											<div class="col-md-6">
												<div class="right-section">
										<?php } ?>
												<article class="wn-pagination magazine-b<?php echo '' . $type; ?> magazine-b<?php echo '' . $type; ?>-cont" data-id="<?php echo '' . $uniqid; ?>">
													<figure class="magazine-b<?php echo '' . $type; ?>-img">
														<img src="<?php echo '' . $thumbnail_url_2; ?>" alt="<?php the_title(); ?>" >
													</figure>
													<div class="magazine-b<?php echo '' . $type; ?>-cont">
														<div class="magazine-b<?php echo '' . $type; ?>-date">
															<i class="pe-7s-clock"></i><?php echo get_the_date(); ?>
														</div>
														<?php $reviews = $reviews == 'show' ? deep_admin_post_review() : ''; ?>
														<h3 class="magazine-b<?php echo '' . $type; ?>-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
													</div>
												</article>
										<?php if ( ( $magazine->current_post + 1 ) == ( $magazine->post_count ) ) { ?>
												</div>
											</div>
										<?php } ?>
									<?php if ( $first_post == true ) { ?>
										</div>
									<?php } ?>
									<?php
								} $first_post = false;
							}
							?>
						</div>
				</div>
			</div><!-- End magazin-wrap  -->
				<?php } ?>
		</div>
			<?php
		} elseif ( $type == '3' ) {
			static $magazin_uniqid = 0;
			$magazin_uniqid++;
			?>

		<div 
			class="magazin-wrap magazin-<?php echo esc_attr( $type ) . ' ' . $shortcodeclass; ?>"
			<?php echo esc_attr( $shortcodeid ); ?>
			data-id="<?php echo esc_attr( $magazin_uniqid ); ?>"
			data-post-name="<?php echo esc_attr( $post_slug ); ?>"
			data-totall_post="<?php echo esc_attr( $totall_post ); ?>"
			data-pagination="<?php echo esc_attr( $pagination ); ?>"
			data-param_category="<?php echo esc_attr( $cat_ids ); ?>"
			data-param_tag="<?php echo esc_attr( $param_tag ); ?>"
			data-post_title="<?php echo esc_html( $post_title ); ?>"
			data-post_url="<?php echo esc_attr( $post_url ); ?>"
			data-type="<?php echo esc_html( $type ); ?>"
			data-sort_order="<?php echo esc_attr( $sort_order ); ?>"
			data-post_number="<?php echo esc_attr( $post_number ); ?>"
			data-post_prepage="<?php echo esc_attr( $post_prepage ); ?>"
			data-excerpt_value="<?php echo esc_attr( $excerpt_value ); ?>"
		>
			<?php
			static $title_uniqid = 0;
			$title_uniqid++;
			$post_title = $post_title ? '<h4 class="magazin-title" data-id="' . $title_uniqid . '">' . $post_title . '</h4>' : '';
			?>
			<div class="clearfix">
				<?php if ( ! empty( $settings['param_category'] ) ) { ?>
					<div class="magazin-cat-nav-wrap">
						<?php echo wp_kses( $post_title, wp_kses_allowed_html( 'post' ) ); ?>
						<ul class="magazin-cat-nav">
							<?php $category_list = '<li><a href="#" class="all cat-item colorf" data-param_category="' . $cat_ids . '">' . esc_html__( 'All', 'deep' ) . '</a></li>'; ?>
							<?php $cat_counter = 0; ?>
							<?php $catsize = sizeof( $settings['param_category'] ); ?>
							<?php
							foreach ( $settings['param_category'] as $id => $cat_slug ) {
								$get_cats = get_category_by_slug( $cat_slug );

								if ( $get_cats ) {
									$cat_id   = $get_cats->term_id;
									$cat_counter++;
									$total_cat_counter = $cat_counter;
									$start_ul          = ( $cat_counter == 5 ) ? '<li class="magazin-dropdown-list"><i class="sl-options"></i><ul>' : '';
									$category_list    .= $start_ul . '<li><a href="#" data-cat-slug="' . deep_get_cat_slug( $cat_id ) . '" class="cat-item" data-param_category="' . $cat_id . '">' . get_the_category_by_ID( $cat_id ) . '</a></li>';
								}								
							}
							if ( $cat_counter == 5 ) {
								if ( $cat_counter == $catsize ) {
									$end_ul         = '</ul></li>';
									$category_list .= $end_ul;
								}
							}
							echo $category_list;
							?>
						</ul>
					</div>
				
				<?php } ?>

				<div class="magazin-wrap-content">
					<?php
					$first_post   = true;
					$post_counter = 0;
					// The Loop
					if ( $magazine->have_posts() ) {
						?>
						<div class="row">
							<?php
							static $uniqid = 0;
							while ( $magazine->have_posts() ) {
								$post_counter++;
								$magazine->the_post();
								$uniqid++;
								$thumbnail_url = get_the_post_thumbnail_url();
								$thumbnail_id  = get_post_thumbnail_id();
								if ( ! empty( $thumbnail_url ) ) {
									if ( ! class_exists( 'Wn_Img_Maniuplate' ) ) {
										require_once DEEP_CORE_DIR . 'helper-classes/class_webnus_manuplate.php';
									}
									$image           = new \Wn_Img_Maniuplate(); // instance from settor class
									$thumbnail_url_1 = $image->m_image( $thumbnail_id, $thumbnail_url, '508', '300' ); // set required and get result
									$thumbnail_url_2 = $image->m_image( $thumbnail_id, $thumbnail_url, '120', '80' ); // set required and get result
								}
								if ( $first_post == true ) {
									?>
									<div class="col-md-6">
										<div class="left-section ">
											<article class="magazine-b<?php echo '' . $type; ?> magazine-b<?php echo '' . $type; ?>-cont" data-id="<?php echo '' . $uniqid; ?>">
												<figure class="magazine-b<?php echo '' . $type; ?>-img">
													<a href="<?php the_permalink(); ?>">
														<img src="<?php echo '' . $thumbnail_url_1; ?>" alt="<?php the_title(); ?>" >
													</a>
												</figure>
												<div class="magazine-b<?php echo '' . $type; ?>-cont">
													<?php
													if ( $hide_cat != 'true' ) {
														?>
														<div class="magazine-b<?php echo '' . $type; ?>-category" style="background: <?php echo deep_category_color(); ?>;">
															<span class="magazine-b<?php echo '' . $type; ?>-cat magazine-cat" data-id="<?php echo '' . $uniqid; ?>"><?php the_category( ', ' ); ?></span>
														</div>
														<?php
													}
													?>
													<div class="magazine-b<?php echo '' . $type; ?>-date">
														<i class="pe-7s-clock"></i><?php echo get_the_date(); ?>
													</div>
													<h3 class="magazine-b<?php echo '' . $type; ?>-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
													<div class="magazine-author">
														<span><?php echo get_avatar( get_the_author_meta( 'user_email' ), 28 ); ?></span>
														<span><?php the_author_posts_link(); ?></span>	
													</div>
													<?php $reviews = $settings['reviews'] == 'show' ? deep_admin_post_review() : ''; ?>
												</div>
											</article>
										</div>
									</div>
								<?php } else { ?>
										<?php if ( $post_counter == 2 ) { ?>
											<div class="col-md-6">
												<div class="left-section">
													<article class="magazine-b<?php echo '' . $type; ?> magazine-b<?php echo '' . $type; ?>-cont" data-id="<?php echo '' . $uniqid; ?>">
														<figure class="magazine-b<?php echo '' . $type; ?>-img">
															<a href="<?php the_permalink(); ?>">
																<img src="<?php echo '' . $thumbnail_url_1; ?>" alt="<?php the_title(); ?>" >
															</a>
														</figure>
														<div class="magazine-b<?php echo '' . $type; ?>-cont">
															<?php
															if ( $hide_cat != 'true' ) {
																?>
																<div class="magazine-b<?php echo '' . $type; ?>-category" style="background: <?php echo deep_category_color(); ?>;">
																	<span class="magazine-b<?php echo '' . $type; ?>-cat magazine-cat" data-id="<?php echo '' . $uniqid; ?>"><?php the_category( ', ' ); ?></span>
																</div>
																<?php
															}
															?>
															<div class="magazine-b<?php echo '' . $type; ?>-date">
																<i class="pe-7s-clock"></i><?php echo get_the_date(); ?>
															</div>
															<h3 class="magazine-b<?php echo '' . $type; ?>-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
															<div class="magazine-author">
																<span><?php echo get_avatar( get_the_author_meta( 'user_email' ), 28 ); ?></span>
																<span><?php the_author_posts_link(); ?></span>	
															</div>
															<?php $reviews = $settings['reviews'] == 'show' ? deep_admin_post_review() : ''; ?>
														</div>
													</article>
												</div>
											</div>
										</div>
										<?php } ?>
									<?php if ( $post_counter >= 3 ) { ?>
										<div class="col-md-6 below-section wn-pagination">
											<article class="magazine-b<?php echo '' . $type; ?> magazine-b<?php echo '' . $type; ?>-cont" data-id="<?php echo '' . $uniqid; ?>">
												<figure class="magazine-b<?php echo '' . $type; ?>-img">
													<a href="<?php the_permalink(); ?>">
														<img src="<?php echo '' . $thumbnail_url_2; ?>" alt="<?php the_title(); ?>" >
													</a>
												</figure>
												<div class="magazine-b<?php echo '' . $type; ?>-cont">
													<div class="magazine-b<?php echo '' . $type; ?>-date">
														<i class="pe-7s-clock"></i><?php echo get_the_date(); ?>
													</div>
													<?php $reviews = $settings['reviews'] == 'show' ? deep_admin_post_review() : ''; ?>
													<h3 class="magazine-b<?php echo '' . $type; ?>-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
												</div>
											</article>
										</div>
									<?php } ?>

									<?php
								} $first_post = false;
							}
							?>
					</div>
				</div>
			</div><!-- End magazin-wrap  -->
				<?php } ?>
			<?php
		}
			wp_reset_postdata();
	}
}
