<?php
class DeepWPBakeryDonate extends DeepWPBakery {
	
	/**
	 * Instance of this class.
	 *
	 * @since   1.0.0
	 * @access  public
	 * @var     DeepWPBakeryDonate
	 */
	public static $instance;

	private $type;

	/**
	 * Provides access to a single instance of a module using the singleton pattern.
	 *
	 * @since   1.0.0
	 * @return  object
	 */
	public static function get_instance() {
		if ( self::$instance === null ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	/**
	 * Define the core functionality of the theme.
	 *
	 * Load the dependencies.
	 *
	 * @since   1.0.0
	 */
	public function __construct() {
		add_shortcode( 'donate', array( $this, 'output' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );			
		add_action( 'wp_head', function() {
			echo '<script>var deep_donate_styles = {}; </script>';
		});
	}

	/**
	 * Shortcode Output.
	 *
	 *
	 * @since   1.0.0
	 */
	public function output( $atts, $content = null ) {		
		extract(shortcode_atts(array(
			'donate_content'	=> '',
			'id'				=> '',
			'color'				=> 'default',
			'size'				=> 'small',
			'border'			=> 'false',
			'icon'				=> 'theme-skin',
			'shortcodeclass' 	=> '',
			'shortcodeid' 	 	=> '',
		), $atts));

		wp_enqueue_style( 'wn-deep-donate', DEEP_ASSETS_URL . 'css/frontend/donate/donate.css' );		
		add_action( 'wp_footer', function() {
			echo '<script>
			var element = document.getElementById("donate.css");
			if(element && !deep_donate_styles["wn-deep-donate-css"]) {
				deep_donate_styles["wn-deep-donate-css"] = true;
				var wrap = document.createElement("div");
				wrap.appendChild(element.cloneNode(true));
				document.getElementsByTagName("head")[0].innerHTML = document.getElementsByTagName("head")[0].innerHTML + wrap.innerHTML;
				if(element.parentNode) {
					element.parentNode.removeChild(element);
				} else {
					element.remove(element);
				}
			}
			</script>';	
		}, 100);

		// Class & ID 
		$shortcodeclass 	= $shortcodeclass ? $shortcodeclass : '';
		$shortcodeid		= $shortcodeid ? ' id="' . $shortcodeid . '"' : '';

		$border 	= ( 'true' == $border ) ? 'bordered-bot' : '';
		$icon_str 	= $icon ? '<i class=" ' . $icon . ' "></i>' : '';
		$theme_skin	= ( $color == 'default' ) ? 'theme-skin' : '' ;
		$out = '
			<a class="donate-button square button '.$theme_skin.' '.$color.' '.$size.' '.$border.' ' . $shortcodeclass . '"  ' . $shortcodeid . '  href="#w-donate-'.get_the_ID().'" data-effect="mfp-zoom-in">
				<span class="media_label">'. $icon_str . $donate_content . '</span>
			</a>
			<div id="w-donate-'.get_the_ID().'" class="white-popup mfp-with-anim mfp-hide">
				<div id="donate-contact-modal-'.get_the_ID().'">
					<div class="w-modal modal-donate wn-donate-contact-modal" id="w-donate-'.get_the_ID().'">
						<h3 class="modal-title">'. $donate_content .'</h3>
						'.do_shortcode('[contact-form-7 id="'.$id.'" title="' . $donate_content . '"]').'
					</div>
				</div>
			</div>';

		return $out;
	}
	
	/**
	 * Required scripts.
	 *
	 * @since   1.0.0
	 */
	public function scripts() {
		if ( self::used_shortcode_in_page( 'donate' ) ) {			
			wp_enqueue_style( 'wn-deep-donate', DEEP_ASSETS_URL . 'css/frontend/donate/donate.css' );				
		}
	}

} DeepWPBakeryDonate::get_instance();
