<?php
class DeepWPBakerySearch extends DeepWPBakery {
	
	/**
	 * Instance of this class.
	 *
	 * @since   1.0.0
	 * @access  public
	 * @var     DeepWPBakerySearch
	 */
	public static $instance;

	private $type;

	/**
	 * Provides access to a single instance of a module using the singleton pattern.
	 *
	 * @since   1.0.0
	 * @return  object
	 */
	public static function get_instance() {
		if ( self::$instance === null ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	/**
	 * Define the core functionality of the theme.
	 *
	 * Load the dependencies.
	 *
	 * @since   1.0.0
	 */
	public function __construct() {
		add_shortcode( 'search', array( $this, 'output' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );			
		add_action( 'wp_head', function() {
			echo '<script>var deep_search_styles = {}; </script>';
		});
	}

	/**
	 * Shortcode Output.
	 *
	 *
	 * @since   1.0.0
	 */
	public function output( $atts, $content = null ) {		
		extract(
			shortcode_atts(
				array(
					'placeholder'		=> '',
					'shortcodeclass' 	=> '',
					'shortcodeid' 	 	=> '',
				),
			$atts )
		);
		wp_enqueue_style( 'wn-deep-search', DEEP_ASSETS_URL . 'css/frontend/search/search.css' );		
		add_action( 'wp_footer', function() {
			echo '<script>
			var element = document.getElementById("search.css");
			if(element && !deep_search_styles["wn-deep-search-css"]) {
				deep_search_styles["wn-deep-search-css"] = true;
				var wrap = document.createElement("div");
				wrap.appendChild(element.cloneNode(true));
				document.getElementsByTagName("head")[0].innerHTML = document.getElementsByTagName("head")[0].innerHTML + wrap.innerHTML;
				if(element.parentNode) {
					element.parentNode.removeChild(element);
				} else {
					element.remove(element);
				}
			}
			</script>';	
		}, 100);

		if ( empty($placeholder) ){
			$placeholder = esc_html__('Enter Keywords...' , 'deep');
		}
		$shortcodeclass 	= $shortcodeclass ? $shortcodeclass : '';
		$shortcodeid		= $shortcodeid ? ' id="' . $shortcodeid . '"' : '';
		$out = '<div class="wn-search-sh ' . $shortcodeclass . '"  ' . $shortcodeid . '>';
		$out .= '<form action="' . esc_url(home_url( '/' )) . '" method="get"><input name="s" type="text" placeholder="'.$placeholder.'" class="wn-search-field" autocomplete="off"> <input type="submit" value="'.esc_html__('Search' , 'deep').'" class="btn"></form>';
		$out .= '</div>';
		return $out;
	}
	
	/**
	 * Required scripts.
	 *
	 * @since   1.0.0
	 */
	public function scripts() {
		if ( self::used_shortcode_in_page( 'search' ) ) {			
			wp_enqueue_style( 'wn-deep-search', DEEP_ASSETS_URL . 'css/frontend/search/search.css' );				
		}
	}

} 
DeepWPBakerySearch::get_instance();
