<?php
class DeepWPBakerySpeakers extends DeepWPBakery {

	/**
	 * Instance of this class.
	 *
	 * @since   1.0.0
	 * @access  public
	 * @var     DeepWPBakerySpeakers
	 */
	public static $instance;

	private $type;

	/**
	 * Provides access to a single instance of a module using the singleton pattern.
	 *
	 * @since   1.0.0
	 * @return  object
	 */
	public static function get_instance() {
		if ( self::$instance === null ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	/**
	 * Define the core functionality of the theme.
	 *
	 * Load the dependencies.
	 *
	 * @since   1.0.0
	 */
	public function __construct() {
		add_shortcode( 'speakers', array( $this, 'output' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );
		add_action( 'wp_head', function() {
			echo '<script>var deep_speakers_styles = {}; </script>';
		});
	}

	/**
	 * Shortcode Output.
	 *
	 *
	 * @since   1.0.0
	 */
	public function output( $attributes, $content = null ) {
		extract(shortcode_atts(	array(
			'hide'				=> '',
			'shortcodeclass' 	=> '',
			'shortcodeid' 	 	=> '',
		), $attributes));
		wp_enqueue_style( 'wn-deep-speakers', DEEP_ASSETS_URL . 'css/frontend/speakers/speakers.css' );
		add_action( 'wp_footer', function() {
			echo '<script>
			var element = document.getElementById("speakers.css");
			if(element && !deep_speakers_styles["wn-deep-speakers-css"]) {
				deep_speakers_styles["wn-deep-speakers-css"] = true;
				var wrap = document.createElement("div");
				wrap.appendChild(element.cloneNode(true));
				document.getElementsByTagName("head")[0].innerHTML = document.getElementsByTagName("head")[0].innerHTML + wrap.innerHTML;
				if(element.parentNode) {
					element.parentNode.removeChild(element);
				} else {
					element.remove(element);
				}
			}
			</script>';
		}, 100);

		ob_start();

		$shortcodeclass 	= $shortcodeclass ? $shortcodeclass : '';
		$shortcodeid		= $shortcodeid ? ' id="' . $shortcodeid . '"' : '';

		echo '<div class="container sermons-speakers ' . $shortcodeclass . '"  ' . $shortcodeid . '>';
		$tax = 'sermon_speaker';
		$hide_empty = ($hide)?true:false;
		$terms = get_terms( $tax, array('hide_empty' => $hide_empty,));
		$speaker_counter = 0;
		foreach( $terms as $term ) {
			if ($speaker_counter == 0){
				echo '<div class="row">';
			}
			$speaker_counter++;
			$sermons_count = $term->count;
			$speaker_detail = term_description( $term->term_id, $tax );
			if ( $sermons_count > 1 ) {
			$w_sermons_count = '<a href="'. get_term_link( $term ) .'">'. str_replace( '%', number_format_i18n( $sermons_count ), __( '% Sermons', 'deep' )) .'</a>';
			} elseif ( $sermons_count == 0 ) {
			$w_sermons_count = __( 'No Sermons', 'deep' );
			} else {
			$w_sermons_count = '<a href="'. get_term_link( $term ) .'">'. __( '1 Sermon', 'deep' ) .'</a>';
			}
			echo '<div class="col-md-4"><article class="speaker">';
			if (function_exists('z_taxonomy_image_url') ){
				echo '<figure><img width="80" src="' . z_taxonomy_image_url($term->term_id,array(300, 300), TRUE) . '"></figure>';
			}
			echo '<h2>'. $term->name .'</h2><h5>'. $w_sermons_count .'</h5>'. $speaker_detail .'</article></div>';
			if ($speaker_counter == 3){
				echo '</div>';
				$speaker_counter = 0;
			}
		}
		if ($speaker_counter != 0){ // if row not full
			echo '</div>'; //close row
		}
		echo '</div>';
		$out = ob_get_contents();
		ob_end_clean();
		wp_reset_postdata();
		return $out;
	}

	/**
	 * Required scripts.
	 *
	 * @since   1.0.0
	 */
	public function scripts() {
		if ( self::used_shortcode_in_page( 'speakers' ) ) {
			wp_enqueue_style( 'wn-deep-speakers', DEEP_ASSETS_URL . 'css/frontend/speakers/speakers.css' );
		}
	}

} DeepWPBakerySpeakers::get_instance();