<?php
class DeepWPBakeryTooltip extends DeepWPBakery {
	
	/**
	 * Instance of this class.
	 *
	 * @since   1.0.0
	 * @access  public
	 * @var     DeepWPBakeryTooltip
	 */
	public static $instance;

	private $type;

	/**
	 * Provides access to a single instance of a module using the singleton pattern.
	 *
	 * @since   1.0.0
	 * @return  object
	 */
	public static function get_instance() {
		if ( self::$instance === null ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	/**
	 * Define the core functionality of the theme.
	 *
	 * Load the dependencies.
	 *
	 * @since   1.0.0
	 */
	public function __construct() {
		add_shortcode( 'tooltip', array( $this, 'output' ) );
		add_action( 'wp_enqueue_scripts', array( $this, 'scripts' ) );			
		add_action( 'wp_head', function() {
			echo '<script>var deep_tooltip_styles = {}; </script>';
		});
	}

	/**
	 * Shortcode Output.
	 *
	 *
	 * @since   1.0.0
	 */
	public function output( $atts, $content = null ) {		
		extract(shortcode_atts(array(
			'tooltiptext'		=> 'Tooltip Text',
			'link_target'		=> '',
			'shortcodeid' 	 	=> '',
			'tooltip_link'		=> '',
			'shortcodeclass' 	=> '',
			'tooltip_content'	=> '',
		), $atts));

		wp_enqueue_style( 'wn-deep-tooltip', DEEP_ASSETS_URL . 'css/frontend/tooltip/tooltip.css' );		
		add_action( 'wp_footer', function() {
			echo '<script>
			var element = document.getElementById("tooltip.css");
			if(element && !deep_tooltip_styles["wn-deep-tooltip-css"]) {
				deep_tooltip_styles["wn-deep-tooltip-css"] = true;
				var wrap = document.createElement("div");
				wrap.appendChild(element.cloneNode(true));
				document.getElementsByTagName("head")[0].innerHTML = document.getElementsByTagName("head")[0].innerHTML + wrap.innerHTML;
				if(element.parentNode) {
					element.parentNode.removeChild(element);
				} else {
					element.remove(element);
				}
			}
			</script>';	
		}, 100);

		$shortcodeclass 	= $shortcodeclass ? $shortcodeclass : '';
		$shortcodeid		= $shortcodeid ? ' id=' . $shortcodeid . '' : '';

		$link_target_tag = '';
		if ( $link_target == 'true' ){
			$link_target_tag = ' target="_blank" ';
		}
		$out = '<span class="tooltips ' . esc_attr( $shortcodeclass ) . '"  ' . esc_attr( $shortcodeid ) . '>';
		$out .= '<a href="' . $tooltip_link . '" '.$link_target_tag.'>';
		$out .= '<span class="tooltip-content">' . $tooltip_content  . '</span>';
		$out .= '<p>' . esc_html( $tooltiptext ) . '</p>';
		$out .= '</a>';
		$out .= '</span>';
		return $out;
	}
	
	/**
	 * Required scripts.
	 *
	 * @since   1.0.0
	 */
	public function scripts() {
		if ( self::used_shortcode_in_page( 'tooltip' ) ) {			
			wp_enqueue_style( 'wn-deep-tooltip', DEEP_ASSETS_URL . 'css/frontend/tooltip/tooltip.css' );				
		}
	}

} DeepWPBakeryTooltip::get_instance();
